@@ -2,38 +2,41 @@
 """
     MoinMoin - MoinMoin.wikidicts tests
 
-    @copyright: 2003-2004 by Jrgen Hermann <jh@web.de>
+    @copyright: 2003-2004 by Juergen Hermann <jh@web.de>,
+                2007 by MoinMoin:ThomasWaldmann
     @license: GNU GPL, see COPYING for details.
 """
 
-import unittest
+import py
 import re
 
-from MoinMoin import wikidicts 
+from MoinMoin import wikidicts
 from MoinMoin import Page
+from MoinMoin.PageEditor import PageEditor
+from MoinMoin._tests.common import gain_superuser_rights
 
-class GroupPageTestCase(unittest.TestCase):
+class TestGroupPage:
 
     def testCamelCase(self):
         """ wikidicts: initFromText: CamelCase links """
         text = """
  * CamelCase
 """
-        self.assertEqual(self.getMembers(text), ['CamelCase'])
+        assert self.getMembers(text) == ['CamelCase']
 
     def testExtendedName(self):
         """ wikidicts: initFromText: extended names """
         text = """
  * extended name
 """
-        self.assertEqual(self.getMembers(text), ['extended name'])
+        assert self.getMembers(text) == ['extended name']
 
     def testExtendedLink(self):
         """ wikidicts: initFromText: extended link """
         text = """
- * ["extended link"]
+ * [[extended link]]
 """
-        self.assertEqual(self.getMembers(text), ['extended link'])
+        assert self.getMembers(text) == ['extended link']
 
     def testIgnoreSecondLevelList(self):
         """ wikidicts: initFromText: ignore non first level items """
@@ -43,7 +46,7 @@ class GroupPageTestCase(unittest.TestCase):
     * forth level
      * and then some...
 """
-        self.assertEqual(self.getMembers(text), [])
+        assert self.getMembers(text) == []
 
     def testIgnoreOther(self):
         """ wikidicts: initFromText: ignore anything but first level list itmes """
@@ -53,22 +56,22 @@ class GroupPageTestCase(unittest.TestCase):
 
 Ignore previous line and this text.
 """
-        self.assertEqual(self.getMembers(text), ['take this'])
+        assert self.getMembers(text) == ['take this']
 
     def testStripWhitespace(self):
         """ wikidicts: initFromText: strip whitespace around items """
         text = """
- *   take this  
+ *   take this
 """
-        self.assertEqual(self.getMembers(text), ['take this'])
-        
+        assert self.getMembers(text) == ['take this']
+
     def getMembers(self, text):
         group = wikidicts.Group(self.request, '')
         group.initFromText(text)
         return group.members()
-        
 
-class DictPageTestCase(unittest.TestCase):
+
+class TestDictPage:
 
     def testGroupMembers(self):
         """ wikidicts: create dict from keys and values in text """
@@ -81,18 +84,17 @@ Text ignored
 
 Empty lines ignored, so is this text
 Next line has key with empty value
- Empty string:: 
+ Empty string::\x20
  Last:: last item
 '''
         d = wikidicts.Dict(self.request, '')
-        d.initFromText(text)        
-        self.assertEqual(d['First'], 'first item')
-        self.assertEqual(d['text with spaces'], 'second item')
-        self.assertEqual(d['Empty string'], '')        
-        self.assertEqual(d['Last'], 'last item')
+        d.initFromText(text)
+        assert d['First'] == 'first item'
+        assert d['text with spaces'] == 'second item'
+        assert d['Empty string'] == '' # XXX fails if trailing blank is missing
+        assert d['Last'] == 'last item'
 
-
-class GroupDictTestCase(unittest.TestCase):
+class TestGroupDicts:
 
     def testSystemPagesGroupInDicts(self):
         """ wikidict: names in SystemPagesGroup should be in request.dicts
@@ -101,9 +103,12 @@ class GroupDictTestCase(unittest.TestCase):
 
         Assume that the SystemPagesGroup is in the data or the underlay dir.
         """
-        assert Page.Page(self.request, 'SystemPagesGroup').exists(), \
-               "SystemPagesGroup is missing, Can't run test"
+        assert Page.Page(self.request, 'SystemPagesGroup').exists(), "SystemPagesGroup is missing, Can't run test"
         systemPages = wikidicts.Group(self.request, 'SystemPagesGroup')
+        #print repr(systemPages)
+        #print repr(self.request.dicts['SystemPagesGroup'])
         for member in systemPages.members():
-            self.assert_(self.request.dicts.has_member('SystemPagesGroup', member),
-                         '%s should be in request.dict' % member)    
+            assert self.request.dicts.has_member('SystemPagesGroup', member), '%s should be in request.dict' % member
+
+coverage_modules = ['MoinMoin.wikidicts']
+
