@@ -6,15 +6,15 @@
     with the same word as the current pagename. If only one matching
     page is found, that page is displayed directly.
 
-    @copyright: (c) 2001 by Richard Jones <richard@bizarsoftware.com.au>
-    @copyright: (c) 2001 by Jrgen Hermann <jh@web.de>
+    @copyright: 2001 Richard Jones <richard@bizarsoftware.com.au>,
+                2001 Juergen Hermann <jh@web.de>
     @license: GNU GPL, see COPYING for details.
 """
 
 import re
 
-from MoinMoin.support import difflib
 from MoinMoin import config, wikiutil
+from MoinMoin.support import difflib
 from MoinMoin.Page import Page
 
 
@@ -24,31 +24,30 @@ def execute(pagename, request):
 
     # Error?
     if isinstance(matches, (str, unicode)):
-        Page(request, pagename).send_page(request, msg=matches)
+        Page(request, pagename).send_page(msg=matches)
         return
 
     # No matches
     if not matches:
-        Page(request, pagename).send_page(request,
-            msg = _('No pages like "%s"!') % (pagename,))
+        Page(request, pagename).send_page(
+             msg=_('No pages like "%s"!', formatted=False) % (pagename,))
         return
 
     # One match - display it
     if len(matches) == 1:
-        Page(request, matches.keys()[0]).send_page(request,
-            msg = _('Exactly one page like "%s" found, redirecting to page.') % (
+        Page(request, matches.keys()[0]).send_page(
+             msg=_('Exactly one page like "%s" found, redirecting to page.', formatted=False) % (
             pagename,))
         return
 
     # more than one match, list 'em
-    request.http_headers()
+    request.emit_http_headers()
 
     # This action generate data using the user language
     request.setContentLanguage(request.lang)
 
-    wikiutil.send_title(request, _('Pages like "%s"') % (pagename),
-                        pagename=pagename)
-        
+    request.theme.send_title(_('Pages like "%s"', formatted=False) % (pagename), pagename=pagename)
+
     # Start content - IMPORTANT - without content div, there is no
     # direction support!
     request.write(request.formatter.startContent("content"))
@@ -57,8 +56,8 @@ def execute(pagename, request):
 
     # End content and send footer
     request.write(request.formatter.endContent())
-    wikiutil.send_footer(request, pagename)
-        
+    request.theme.send_footer(pagename)
+    request.theme.send_closing_html()
 
 def findMatches(pagename, request, s_re=None, e_re=None,):
     """ Find like pages
@@ -100,13 +99,13 @@ def findMatches(pagename, request, s_re=None, e_re=None,):
             # Stop after 10 matches
             if found == 10:
                 break
-    
+
     # Filter deleted pages or pages the user can't read from
     # matches. Order is important!
-    for name in matches.keys():
+    for name in matches.keys(): # we need .keys() because we modify the dict
         page = Page(request, name)
         if not (page.exists() and request.user.may.read(name)):
-            del matches[name]    
+            del matches[name]
 
     # Finally, merge both dicts
     matches.update(close_matches)
@@ -132,11 +131,11 @@ def wikiMatches(pagename, pages, start_re=None, end_re=None):
     @return: start, end, matches dict
     """
     if start_re is None:
-        start_re=re.compile('([%s][%s]+)' % (config.chars_upper,
-                                             config.chars_lower))
+        start_re = re.compile('([%s][%s]+)' % (config.chars_upper,
+                                               config.chars_lower))
     if end_re is None:
-        end_re=re.compile('([%s][%s]+)$' % (config.chars_upper,
-                                            config.chars_lower))
+        end_re = re.compile('([%s][%s]+)$' % (config.chars_upper,
+                                              config.chars_lower))
 
     # If we don't get results with wiki words matching, fall back to
     # simple first word and last word, using spaces.
@@ -145,14 +144,14 @@ def wikiMatches(pagename, pages, start_re=None, end_re=None):
     if match:
         start = match.group(1)
     else:
-       start = words[0] 
-        
+        start = words[0]
+
     match = end_re.search(pagename)
     if match:
         end = match.group(1)
     else:
-        end = words[-1] 
-    
+        end = words[-1]
+
     matches = {}
     subpage = pagename + '/'
 
@@ -202,7 +201,7 @@ def closeMatches(pagename, pages):
     return matches
 
 
-def showMatches(pagename, request, start, end, matches, show_count = True):
+def showMatches(pagename, request, start, end, matches, show_count=True):
     keys = matches.keys()
     keys.sort()
     _showMatchGroup(request, matches, keys, 8, pagename, show_count)
@@ -212,7 +211,7 @@ def showMatches(pagename, request, start, end, matches, show_count = True):
     _showMatchGroup(request, matches, keys, 2, "...%s" % (end,), show_count)
 
 
-def _showMatchGroup(request, matches, keys, match, title, show_count = True):
+def _showMatchGroup(request, matches, keys, match, title, show_count=True):
     _ = request.getText
     matchcount = matches.values().count(match)
 
@@ -221,9 +220,9 @@ def _showMatchGroup(request, matches, keys, match, title, show_count = True):
             # Render title line
             request.write(request.formatter.paragraph(1))
             request.write(request.formatter.strong(1))
-            request.write(_('%(matchcount)d %(matches)s for "%(title)s"') % {
+            request.write(_('%(matchcount)d %(matches)s for "%(title)s"', formatted=False) % {
                 'matchcount': matchcount,
-                'matches': ' ' + (_('match'), _('matches'))[matchcount != 1],
+                'matches': ' ' + (_('match', formatted=False), _('matches', formatted=False))[matchcount != 1],
                 'title': wikiutil.escape(title)})
             request.write(request.formatter.strong(0))
             request.write(request.formatter.paragraph(0))
@@ -233,9 +232,9 @@ def _showMatchGroup(request, matches, keys, match, title, show_count = True):
         for key in keys:
             if matches[key] == match:
                 request.write(request.formatter.listitem(1))
-                request.write(request.formatter.pagelink(1, key))
+                request.write(request.formatter.pagelink(1, key, generated=True))
                 request.write(request.formatter.text(key))
-                request.write(request.formatter.pagelink(0, key))
+                request.write(request.formatter.pagelink(0, key, generated=True))
                 request.write(request.formatter.listitem(0))
         request.write(request.formatter.bullet_list(0))
 
