@@ -18,11 +18,11 @@
               WikiWiki
                    OriginalWiki
 
-    @copyright: 2001 by Steve Howell <showell@zipcon.com>
-    @copyright: 2001-2004 by Jrgen Hermann <jh@web.de>
+    @copyright: 2001 Steve Howell <showell@zipcon.com>,
+                2001-2004 Juergen Hermann <jh@web.de>
     @license: GNU GPL, see COPYING for details.
 """
-    
+
 from MoinMoin import wikiutil
 from MoinMoin.Page import Page
 
@@ -31,13 +31,12 @@ class MaxNodesReachedException(Exception):
 
 def execute(pagename, request):
     _ = request.getText
-    request.http_headers()
+    request.emit_http_headers()
 
     # This action generate data using the user language
     request.setContentLanguage(request.lang)
 
-    wikiutil.send_title(request, _('Local Site Map for "%s"') % (pagename),  
-        pagename=pagename)
+    request.theme.send_title(_('Local Site Map for "%s"', formatted=False) % (pagename), pagename=pagename)
 
     # Start content - IMPORTANT - witout content div, there is no
     # direction support!
@@ -45,11 +44,9 @@ def execute(pagename, request):
 
     request.write(LocalSiteMap(pagename).output(request))
 
-    # End content
     request.write(request.formatter.endContent()) # end content div
-    # Footer
-    wikiutil.send_footer(request, pagename)
-
+    request.theme.send_footer(pagename)
+    request.theme.send_closing_html()
 
 class LocalSiteMap:
     def __init__(self, name):
@@ -70,12 +67,14 @@ class LocalSiteMap:
     def visit(self, request, name, depth):
         """ Visit a page, i.e. create a link.
         """
-        if not name: return
-        self.append('&nbsp;' * (5*depth))
-        self.append('&nbsp;' + wikiutil.link_tag(request, '%s?action=%s' %
-            (wikiutil.quoteWikinameURL(name), __name__.split('.')[-1]), wikiutil.escape(name)))
+        if not name:
+            return
+        pg = Page(request, name)
+        action = __name__.split('.')[-1]
+        self.append('&nbsp;' * (5*depth+1))
+        self.append(pg.link_to(request, wikiutil.escape(name), querystr={'action': action}))
         self.append("&nbsp;<small>[")
-        self.append(Page(request, name).link_to(request, 'view'))
+        self.append(pg.link_to(request, 'view'))
         self.append("</small>]<br>")
 
     def append(self, text):
@@ -93,7 +92,7 @@ class PageTreeBuilder:
         self.children[name] = 1
 
     def child_marked(self, name):
-        return self.children.has_key(name)
+        return name in self.children
 
     def is_ok(self, child):
         if not self.child_marked(child):
@@ -107,10 +106,10 @@ class PageTreeBuilder:
     def new_kids(self, name):
         # does not recurse
         kids = []
-        for child in Page(self.request, name).getPageLinks(self.request):            
+        for child in Page(self.request, name).getPageLinks(self.request):
             if self.is_ok(child):
                 kids.append(child)
-        return kids        
+        return kids
 
     def new_node(self):
         self.numnodes = self.numnodes + 1
@@ -145,7 +144,7 @@ class Tree:
 
     def append(self, node):
         self.children.append(node)
- 
+
     def depth_first_visit(self, request, visitor, depth=0):
         visitor.visit(request, self.node, depth)
         for c in self.children:
