@@ -15,8 +15,8 @@
     Additionally, all words on the page "LocalSpellingWords" are added to
     the list of valid words, if that page exists.
 
-    @copyright: 2001 by Richard Jones <richard@bizarsoftware.com.au>  
-    @copyright: 2001-2004 by Jrgen Hermann <jh@web.de>  
+    @copyright: 2001 Richard Jones <richard@bizarsoftware.com.au>,
+                2001-2004 Juergen Hermann <jh@web.de>  
     @license: GNU GPL, see COPYING for details.  
 """
 
@@ -30,16 +30,17 @@ def _getWordsFiles(request):
     candidates = []
 
     # load a list of possible word files
-    localdict = os.path.join(request.cfg.moinmoin_dir, 'dict')
-    if os.path.isdir(localdict):
-        candidates.extend(map(
-            lambda f, d=localdict: os.path.join(d, f), os.listdir(localdict)))
+    for basedir in (request.cfg.moinmoin_dir, request.cfg.data_dir):
+        localdict = os.path.join(basedir, 'dict')
+        if os.path.isdir(localdict):
+            candidates.extend(
+                [os.path.join(localdict, fn) for fn in os.listdir(localdict)])
 
     # validate candidate list (leave out directories!)
     wordsfiles = []
-    for file in candidates:
-        if os.path.isfile(file) and os.access(file, os.F_OK | os.R_OK):
-            wordsfiles.append(file)
+    for f in candidates:
+        if os.path.isfile(f) and os.access(f, os.F_OK | os.R_OK):
+            wordsfiles.append(f)
 
     # return validated file list
     return wordsfiles
@@ -52,12 +53,16 @@ def _loadWords(lines, dict):
 
 def _loadWordsFile(request, dict, filename):
     request.clock.start('spellread')
-    file = codecs.open(filename, 'rt', config.charset)
     try:
-        lines = file.readlines()
-        _loadWords(lines, dict)
+        try:
+            f = codecs.open(filename, 'rt', config.charset)
+            lines = f.readlines()
+        except UnicodeError:
+            f = codecs.open(filename, 'rt', 'iso-8859-1')
+            lines = f.readlines()
     finally:
-        file.close()
+        f.close()
+    _loadWords(lines, dict)
     request.clock.stop('spellread')
 
 def _loadWordsPage(request, dict, page):
@@ -80,7 +85,7 @@ def _loadDict(request):
     else:
         wordsfiles = _getWordsFiles(request)
         if dbhash:
-            wordsdict = dbhash.open(cachename, 'n', 0666 & config.umask)
+            wordsdict = dbhash.open(cachename, 'n')
         else:
             wordsdict = {}
 
@@ -94,9 +99,7 @@ def _loadDict(request):
 
 
 def _addLocalWords(request):
-    import types
     from MoinMoin.PageEditor import PageEditor
-
     # get the new words as a string (if any are marked at all)
     try:
         newwords = request.form['newwords']
@@ -104,7 +107,7 @@ def _addLocalWords(request):
         # no new words checked
         return
     newwords = u' '.join(newwords)
-    
+
     # get the page contents
     lsw_page = PageEditor(request, request.cfg.page_local_spelling_words)
     words = lsw_page.get_raw_body()
@@ -121,7 +124,7 @@ def checkSpelling(page, request, own_form=1):
     _ = request.getText
 
     # first check to see if we we're called with a "newwords" parameter
-    if request.form.has_key('button_newwords'):
+    if 'button_newwords' in request.form:
         _addLocalWords(request)
 
     # load words
@@ -148,34 +151,33 @@ def checkSpelling(page, request, own_form=1):
             return ""
         w_enc = word.encode(config.charset)
         wl_enc = word.lower().encode(config.charset)
-        if not (wordsdict.has_key(w_enc) or
-                wordsdict.has_key(wl_enc) or
-                localwords.has_key(w_enc) or
-                localwords.has_key(wl_enc) ):
+        if not (w_enc in wordsdict or wl_enc in wordsdict or
+                w_enc in localwords or wl_enc in localwords):
             if not num_re.match(word):
                 badwords[word] = 1
         return ""
 
     # do the checking
     for line in text.split('\n'):
-        if line == '' or line[0] == '#': continue
+        if line == '' or line[0] == '#':
+            continue
         word_re.sub(checkword, line)
 
     if badwords:
         badwords = badwords.keys()
-        badwords.sort(lambda x,y: cmp(x.lower(), y.lower()))
+        badwords.sort(lambda x, y: cmp(x.lower(), y.lower()))
 
         # build regex recognizing the bad words
         badwords_re = r'(^|(?<!\w))(%s)(?!\w)'
-        badwords_re = badwords_re % ("|".join(map(re.escape, badwords)),)
+        badwords_re = badwords_re % ("|".join([re.escape(bw) for bw in badwords]),)
         badwords_re = re.compile(badwords_re, re.UNICODE)
 
         lsw_msg = ''
         if localwords:
-            lsw_msg = ' ' + _('(including %(localwords)d %(pagelink)s)') % {
+            lsw_msg = ' ' + _('(including %(localwords)d %(pagelink)s)', formatted=False) % {
                 'localwords': len(localwords), 'pagelink': lsw_page.link_to(request)}
         msg = _('The following %(badwords)d words could not be found in the dictionary of '
-                '%(totalwords)d words%(localwords)s and are highlighted below:') % {
+                '%(totalwords)d words%(localwords)s and are highlighted below:', formatted=False) % {
             'badwords': len(badwords),
             'totalwords': len(wordsdict)+len(localwords),
             'localwords': lsw_msg} + "<br>"
@@ -185,20 +187,20 @@ def checkSpelling(page, request, own_form=1):
 
         # add a form containing the bad words
         if own_form:
-            msg = msg + ('<form method="post" action="">\n'
-                         '<input type="hidden" name="action" value="%s">\n') % action_name
-        
+            msg = msg + ('<form method="post" action="%s/%s">\n'
+                         '<input type="hidden" name="action" value="%s">\n') % (request.getScriptname(), wikiutil.quoteWikinameURL(page.page_name), action_name)
+
         checkbox = '<input type="checkbox" name="newwords" value="%(word)s">%(word)s&nbsp;&nbsp;'
         msg = msg + (
-            " ".join(map(lambda w, cb=checkbox: cb % {'word': wikiutil.escape(w),}, badwords)) +
+            " ".join([checkbox % { 'word': wikiutil.escape(w), } for w in badwords]) +
             '<p><input type="submit" name="button_newwords" value="%s"></p>' %
-                _('Add checked words to dictionary')
+                _('Add checked words to dictionary', formatted=False)
         )
         if own_form:
             msg = msg + '</form>'
     else:
         badwords_re = None
-        msg = _("No spelling errors found!")
+        msg = _("No spelling errors found!", formatted=False)
 
     request.clock.stop('spellcheck')
 
@@ -207,15 +209,21 @@ def checkSpelling(page, request, own_form=1):
 
 def execute(pagename, request):
     _ = request.getText
+
     page = Page(request, pagename)
+    if not request.user.may.write(request.cfg.page_local_spelling_words):
+        msg = _("You can't save spelling words.", formatted=False)
+        page.send_page(msg=msg)
+        return
+
     if request.user.may.read(pagename):
         badwords, badwords_re, msg = checkSpelling(page, request)
     else:
         badwords = []
-        msg = _("You can't check spelling on a page you can't read.")
+        msg = _("You can't check spelling on a page you can't read.", formatted=False)
 
     if badwords:
-        page.send_page(request, msg=msg, hilite_re=badwords_re)
+        page.send_page(msg=msg, hilite_re=badwords_re)
     else:
-        page.send_page(request, msg=msg)
+        page.send_page(msg=msg)
 
