@@ -2,47 +2,47 @@
    MoinMoin - Subscribeuser - Action
    Subscribe a user to a page
 
-   @copyright: Daniela Nicklas <nicklas@informatik.uni-stuttgart.de>, 2003
-   @copyright: 2005 MoinMoin:AlexanderSchremmer
-   
+   @copyright: 2003 Daniela Nicklas <nicklas@informatik.uni-stuttgart.de>,
+               2005 MoinMoin:AlexanderSchremmer
    @license: GNU GPL, see COPYING for details.
 """
 
 import sys, os
 #sys.path.append("YOUR CONFIG DIRECTORY HERE")
 
-from MoinMoin import wikiutil
 from MoinMoin.Page import Page
 from MoinMoin import user
+from MoinMoin import wikiutil
 
 def show_form(pagename, request):
     _ = request.getText
-    request.http_headers()
-    wikiutil.send_title(request, _("Subscribe users to the page %s") % pagename, pagename=pagename)
+    request.emit_http_headers()
+    request.theme.send_title(_("Subscribe users to the page %s", formatted=False) % pagename, pagename=pagename)
 
     request.write("""
-<form action="" method="POST" enctype="multipart/form-data">
+<form action="%s/%s" method="POST" enctype="multipart/form-data">
 <input type="hidden" name="action" value="SubscribeUser">
-Enter user names (comma separated): <input type="text" name="users" size="50">
+%s <input type="text" name="users" size="50">
 <input type="submit" value="Subscribe">
 </form>
-""")
-    wikiutil.send_footer(request, pagename)
+""" % (request.getScriptname(), wikiutil.quoteWikinameURL(pagename), _("Enter user names (comma separated):", formatted=False)))
+    request.theme.send_footer(pagename)
+    request.theme.send_closing_html()
 
 def show_result(pagename, request):
     _ = request.getText
-    request.http_headers()
+    request.emit_http_headers()
 
-    wikiutil.send_title(request, _("Subscribed for %s:") % pagename, pagename=pagename)
+    request.theme.send_title(_("Subscribed for %s:", formatted=False) % pagename, pagename=pagename)
 
     from MoinMoin.formatter.text_html import Formatter
     formatter = Formatter(request)
-    
+
     result = subscribe_users(request, request.form['users'][0].split(","), pagename, formatter)
     request.write(result)
 
-    wikiutil.send_footer(request, pagename)
-
+    request.theme.send_footer(pagename)
+    request.theme.send_closing_html()
 
 def subscribe_users(request, usernamelist, pagename, formatter):
     _ = request.getText
@@ -78,19 +78,19 @@ def subscribe_users(request, usernamelist, pagename, formatter):
             result.append(formatter.url(0))
             result.append(formatter.linebreak(preformatted=0))
 
-    result.extend([''.join([formatter.smiley('{X}'), formatter.text(" " + _("Not a user:") + " " + username), formatter.linebreak(preformatted=0)]) for username in usernamelist if username not in realusers])
+    result.extend([''.join([formatter.smiley('{X}'), formatter.text(" " + _("Not a user:", formatted=False) + " " + username), formatter.linebreak(preformatted=0)]) for username in usernamelist if username not in realusers])
 
     return ''.join(result)
-    
+
 def execute(pagename, request):
     _ = request.getText
     if not request.user.may.admin(pagename):
-        request.http_headers()
-        wikiutil.send_title(request, _("You are not allowed to perform this action."), pagename=pagename)
-    elif not request.form.has_key('users'):
+        thispage = Page(request, pagename)
+        return thispage.send_page(msg=_("You are not allowed to perform this action.", formatted=False))
+    elif 'users' not in request.form:
         show_form(pagename, request)
     else:
-        show_result(pagename,request)
+        show_result(pagename, request)
 
 if __name__ == '__main__':
     args = sys.argv
@@ -117,8 +117,8 @@ Example:
         request_url = "localhost/"
 
     # Setup MoinMoin environment
-    from MoinMoin.request import RequestCLI
-    request = RequestCLI(url=request_url)
+    from MoinMoin.request import request_cli
+    request = request_cli.Request(url=request_url)
     request.form = request.args = request.setup_args()
 
     from MoinMoin.formatter.text_plain import Formatter
