@@ -2,7 +2,7 @@
 """
     MoinMoin - feed some FCKeditor dialogues
 
-    @copyright: (c) Bastian Blank, Florian Festi, Thomas Waldmann
+    @copyright: 2005-2006 Bastian Blank, Florian Festi, Thomas Waldmann
     @license: GNU GPL, see COPYING for details.
 """
 
@@ -15,7 +15,7 @@ import re
 
 def macro_dialog(request):
     help = get_macro_help(request)
-    request.http_headers()
+    request.emit_http_headers()
     request.write(
         '''<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0 Transitional//EN">
 <html>
@@ -87,7 +87,7 @@ function OnChange( sMacro )
        <td valign="top">
        <span fckLang="MacroDlgName">Macro Name</span><br>
        <select id="txtName" size="10" onchange="OnChange(this.value);">
-''' % request.cfg.url_prefix)
+''' % request.cfg.url_prefix_static)
 
     macros = []
     for macro in macro_list(request):
@@ -95,7 +95,7 @@ function OnChange( sMacro )
             selected = ' selected="selected"'
         else:
             selected = ''
-        if help.has_key(macro):
+        if macro in help:
             macros.append('<option value="%s"%s>%s</option>' %
                           (help[macro].group('prototype'), selected, macro))
         else:
@@ -110,7 +110,7 @@ function OnChange( sMacro )
 
     helptexts = []
     for macro in macro_list(request):
-        if help.has_key(macro):
+        if macro in help:
             match = help[macro]
             prototype = match.group('prototype')
             helptext = match.group('help')
@@ -119,7 +119,7 @@ function OnChange( sMacro )
             helptext = ""
         helptexts.append(
             '''<div id="%s" style="DISPLAY: none">
-               <b>[[%s]]</b>
+               <b>&lt;&lt;%s&gt;&gt;</b>
                <br/>
                <textarea style="color:#000000" cols="37" rows="10" disabled="disabled">%s</textarea>
                </div>'''
@@ -136,22 +136,23 @@ function OnChange( sMacro )
 </body>
 </html>
 ''')
-        
+
 def macro_list(request):
-    from MoinMoin import wikimacro
-    macros = wikimacro.getNames(request.cfg)
+    from MoinMoin import macro
+    macros = macro.getNames(request.cfg)
     macros.sort()
     return macros
 
 def get_macro_help(request):
     """ Read help texts from SystemPage('HelpOnMacros')"""
-    helppage = wikiutil.getSysPage(request, "HelpOnMacros")
+    helppage = wikiutil.getLocalizedPage(request, "HelpOnMacros")
     content = helppage.get_raw_body()
     macro_re = re.compile(
-        r"\|\|(<.*?>)?\{\{\{\[\[" +
-        r"(?P<prototype>(?P<macro>\w*).*)" +
-        r"\]\]\}\}\}\s*\|\|" + 
-        r"\s*(?P<help>.*?)\s*\|\|\s*(?P<example>.*?)\s*\|\|$", re.U + re.M)
+        r"\|\|(<.*?>)?\{\{\{" +
+        r"<<(?P<prototype>(?P<macro>\w*).*)>>" +
+        r"\}\}\}\s*\|\|" +
+        r"[^|]*\|\|[^|]*\|\|<[^>]*>" +
+        r"\s*(?P<help>.*?)\s*\|\|\s*(?P<example>.*?)\s*(<<[^>]*>>)*\s*\|\|$", re.U|re.M)
     help = {}
     for match in macro_re.finditer(content):
         help[match.group('macro')] = match
@@ -163,16 +164,13 @@ def get_macro_help(request):
 
 def page_list(request):
     from MoinMoin import search
-    name = request.form.get("pagename",[""])[0]
+    name = request.form.get("pagename", [""])[0]
     if name:
-        searchresult = search.searchPages(
-            request,
-            search.QueryParser().parse_query('t:"%s"' % name))
-        
+        searchresult = search.searchPages(request, 't:"%s"' % name)
         pages = [p.page_name for p in searchresult.hits]
     else:
         pages = [name]
-    request.http_headers()
+    request.emit_http_headers()
     request.write(
         '''<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0 Transitional//EN">
 <html>
@@ -203,20 +201,18 @@ def page_list(request):
 ''' % "".join(["<option>%s</option>\n" % p for p in pages]))
 
 def link_dialog(request):
-    request.http_headers()
+    request.emit_http_headers()
     # list of wiki pages
     name = request.form.get("pagename", [""])[0]
     if name:
         from MoinMoin import search
         # XXX error handling!
-        searchresult = search.searchPages(
-            request,
-            search.QueryParser().parse_query('t:"%s"' % name))
-        
+        searchresult = search.searchPages(request, 't:"%s"' % name)
+
         pages = [p.page_name for p in searchresult.hits]
         pages.sort()
         pages[0:0] = [name]
-        page_list ='''
+        page_list = '''
          <tr>
           <td colspan=2>
            <select id="sctPagename" size="1" onchange="OnChangePagename(this.value);">
@@ -228,13 +224,13 @@ def link_dialog(request):
                  for page in pages])
     else:
         page_list = ""
-    
+
     # list of interwiki names
-    wikiutil.resolve_wiki(request, "Self:FrontPage")
-    interwiki = request.cfg._interwiki_list.keys()
+    interwiki_list = wikiutil.load_wikimap(request)
+    interwiki = interwiki_list.keys()
     interwiki.sort()
-    iwpreferred = request.cfg.interwiki_preferred
-    if not iwpreferred or iwpreferred and iwpreferred[-1] != None:
+    iwpreferred = request.cfg.interwiki_preferred[:]
+    if not iwpreferred or iwpreferred and iwpreferred[-1] is not None:
         resultlist = iwpreferred
         for iw in interwiki:
             if not iw in iwpreferred:
@@ -245,13 +241,12 @@ def link_dialog(request):
         ['<option value="%s">%s</option>' % (key, key) for key in resultlist])
 
     # wiki url
-    url_prefix = request.cfg.url_prefix
+    url_prefix_static = request.cfg.url_prefix_static
     scriptname = request.getScriptname()
     if not scriptname or scriptname[-1] != "/":
         scriptname += "/"
     action = scriptname
     basepage = request.page.page_name.encode(config.charset)
-    request.http_headers()
     request.write('''
 <!--
  * FCKeditor - The text editor for internet
@@ -280,9 +275,9 @@ def link_dialog(request):
   <title>Link Properties</title>
   <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
   <meta name="robots" content="noindex,nofollow" />
-  <script src="%(url_prefix)s/applets/FCKeditor/editor/dialog/common/fck_dialog_common.js" type="text/javascript"></script>
-  <script src="%(url_prefix)s/applets/moinFCKplugins/moinlink/fck_link.js" type="text/javascript"></script>
-  <script src="%(url_prefix)s/applets/moinFCKplugins/moinurllib.js" type="text/javascript"></script>
+  <script src="%(url_prefix_static)s/applets/FCKeditor/editor/dialog/common/fck_dialog_common.js" type="text/javascript"></script>
+  <script src="%(url_prefix_static)s/applets/moinFCKplugins/moinlink/fck_link.js" type="text/javascript"></script>
+  <script src="%(url_prefix_static)s/applets/moinFCKplugins/moinurllib.js" type="text/javascript"></script>
  </head>
  <body scroll="no" style="OVERFLOW: hidden">
   <div id="divInfo" style="DISPLAY: none">
@@ -372,20 +367,18 @@ def link_dialog(request):
 ##############################################################################
 
 def attachment_dialog(request):
-    request.http_headers()
+    request.emit_http_headers()
     # list of wiki pages
     name = request.form.get("pagename", [""])[0]
     if name:
         from MoinMoin import search
         # XXX error handling!
-        searchresult = search.searchPages(
-            request,
-            search.QueryParser().parse_query('t:"%s"' % name))
-        
+        searchresult = search.searchPages(request, 't:"%s"' % name)
+
         pages = [p.page_name for p in searchresult.hits]
         pages.sort()
         pages[0:0] = [name]
-        page_list ='''
+        page_list = '''
          <tr>
           <td colspan=2>
            <select id="sctPagename" size="1" onchange="OnChangePagename(this.value);">
@@ -397,14 +390,13 @@ def attachment_dialog(request):
                  for page in pages])
     else:
         page_list = ""
-    
+
     # wiki url
-    url_prefix = request.cfg.url_prefix
+    url_prefix_static = request.cfg.url_prefix_static
     scriptname = request.getScriptname()
     if not scriptname or scriptname[-1] != "/":
         scriptname += "/"
     action = scriptname
-    request.http_headers()
     request.write('''
 <!--
  * FCKeditor - The text editor for internet
@@ -433,9 +425,9 @@ def attachment_dialog(request):
   <title>Attachment Properties</title>
   <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
   <meta name="robots" content="noindex,nofollow" />
-  <script src="%(url_prefix)s/applets/FCKeditor/editor/dialog/common/fck_dialog_common.js" type="text/javascript"></script>
-  <script src="%(url_prefix)s/applets/moinFCKplugins/moinattachment/fck_attachment.js" type="text/javascript"></script>
-  <script src="%(url_prefix)s/applets/moinFCKplugins/moinurllib.js" type="text/javascript"></script>
+  <script src="%(url_prefix_static)s/applets/FCKeditor/editor/dialog/common/fck_dialog_common.js" type="text/javascript"></script>
+  <script src="%(url_prefix_static)s/applets/moinFCKplugins/moinattachment/fck_attachment.js" type="text/javascript"></script>
+  <script src="%(url_prefix_static)s/applets/moinFCKplugins/moinurllib.js" type="text/javascript"></script>
  </head>
  <body scroll="no" style="OVERFLOW: hidden">
   <div id="divInfo">
@@ -469,8 +461,8 @@ def attachment_dialog(request):
 ##############################################################################
 
 def image_dialog(request):
-    request.http_headers()
-    url_prefix = request.cfg.url_prefix
+    request.emit_http_headers()
+    url_prefix_static = request.cfg.url_prefix_static
     request.write('''
 <!--
  * FCKeditor - The text editor for internet
@@ -492,9 +484,9 @@ def image_dialog(request):
   <title>Link Properties</title>
   <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
   <meta name="robots" content="noindex,nofollow" />
-  <script src="%(url_prefix)s/applets/FCKeditor/editor/dialog/common/fck_dialog_common.js" type="text/javascript"></script>
-  <script src="%(url_prefix)s/applets/moinFCKplugins/moinimage/fck_image.js" type="text/javascript"></script>
-  <script src="%(url_prefix)s/applets/moinFCKplugins/moinurllib.js" type="text/javascript"></script>
+  <script src="%(url_prefix_static)s/applets/FCKeditor/editor/dialog/common/fck_dialog_common.js" type="text/javascript"></script>
+  <script src="%(url_prefix_static)s/applets/moinFCKplugins/moinimage/fck_image.js" type="text/javascript"></script>
+  <script src="%(url_prefix_static)s/applets/moinFCKplugins/moinurllib.js" type="text/javascript"></script>
  </head>
  <body scroll="no" style="OVERFLOW: hidden">
     <table cellspacing="0" cellpadding="0" width="100%%" border="0">
@@ -537,7 +529,7 @@ def execute(pagename, request):
     if dialog == "macro":
         macro_dialog(request)
     elif dialog == "macrolist":
-        macrolist(request)
+        macro_list(request)
     elif dialog == "pagelist":
         page_list(request)
     elif dialog == "link":
@@ -548,5 +540,5 @@ def execute(pagename, request):
         image_dialog(request)
     else:
         from MoinMoin.Page import Page
-        Page(request, pagename).send_page(request, msg="Dialog unknown!")
+        Page(request, pagename).send_page(msg="Dialog unknown!")
 
