@@ -3,15 +3,14 @@
 
     Create a new page with optional template. Can be used with NewPage.py macro.
 
-    @copyright: 2004 Vito Miliano (vito_moinnewpagewithtemplate@perilith.com)
-    @copyright: 2004 by Nir Soffer <nirs@freeshell.org>
-    @copyright: 2004 Alexander Schremmer <alex AT alexanderweb DOT de>
+    @copyright: 2004 Vito Miliano (vito_moinnewpagewithtemplate@perilith.com),
+                2004 Nir Soffer <nirs@freeshell.org>,
+                2004 Alexander Schremmer <alex AT alexanderweb DOT de>
     @license: GNU GPL, see COPYING for details.
 """
 
-from MoinMoin.util import MoinMoinNoFooter
-from MoinMoin.Page import Page
 import time
+from MoinMoin.Page import Page
 
 class NewPage:
     """ Open editor for a new page, using template """
@@ -21,7 +20,7 @@ class NewPage:
         self.referrer = referrer # The page the user came from
         self.pagename = self.request.form.get('pagename', [None])[0]
         self.nametemplate = self.request.form.get('nametemplate', ['%s'])[0]
-        self.nametemplate = self.nametemplate.replace('\x00','')
+        self.nametemplate = self.nametemplate.replace('\x00', '')
 
     def checkAndCombineArguments(self):
         """ Check arguments in form, return error msg
@@ -30,17 +29,17 @@ class NewPage:
         @return: error message
         """
         _ = self.request.getText
-        need_replace = self.nametemplate.find('%s') != -1
+        need_replace = '%s' in self.nametemplate
         if not self.pagename and need_replace:
             return _("Cannot create a new page without a page name."
-                     "  Please specify a page name.")
-        if need_replace: 
-	    # generate a string that can be safely used as the pagename
-	    # template variable
+                     "  Please specify a page name.", formatted=False)
+        if need_replace:
+        # generate a string that can be safely used as the pagename
+        # template variable
             repl = 'A@'
             i = 0
-            while self.nametemplate.find(repl) != -1:
-                repl += ['#','&','$','x','X',':','@'][i]
+            while repl in self.nametemplate:
+                repl += ['#', '&', '$', 'x', 'X', ':', '@'][i]
                 i += 1
                 i = i % 7
             template = self.nametemplate.replace('%s', repl)
@@ -54,7 +53,7 @@ class NewPage:
         else:
             self.pagename = template
         return ''
-        
+
     def checkPermissions(self):
         """ Check write permission in form, return error msg
 
@@ -65,17 +64,16 @@ class NewPage:
         page = Page(self.request, self.pagename)
         if not (page.isWritable() and self.request.user.may.read(self.pagename)):
             # Same error as the edit page for localization reasons
-            return _('You are not allowed to edit this page.')
+            return _('You are not allowed to edit this page.', formatted=False)
         return ''
 
     def render(self):
         """ Redirect to the new page, using edit action and template """
-        
         error = self.checkAndCombineArguments() or self.checkPermissions()
         if error:
             # Send back to the page you came from, with an error msg
             page = Page(self.request, self.referrer)
-            page.send_page(self.request, msg=error)
+            page.send_page(msg=error)
         else:
             # Redirect to new page using edit action. No error checking
             # is needed because it is done later in new request.
@@ -84,16 +82,14 @@ class NewPage:
 
             template = self.request.form.get('template', [''])[0]
             if template:
-                from MoinMoin.wikiutil import quoteWikinameURL
-                query['template'] = quoteWikinameURL(template)
+                query['template'] = template
 
             parent = self.request.form.get('parent', [''])[0]
             if parent:
                 pagename = "%s/%s" % (parent, pagename)
 
-            url = Page(self.request, pagename).url(self.request, query, 0)
+            url = Page(self.request, pagename).url(self.request, query, relative=False)
             self.request.http_redirect(url)
-            raise MoinMoinNoFooter
 
         return ''
 
