@@ -2,17 +2,16 @@
 """
     MoinMoin - Filter Package
 
-    @copyright: 2006 by Thomas Waldmann
+    @copyright: 2006 Thomas Waldmann
     @license: GNU GPL, see COPYING for details.
 """
 
 import os
 from MoinMoin.util import pysupport
 
-filters = pysupport.getPackageModules(__file__)
-modules = filters
+modules = pysupport.getPackageModules(__file__)
 
-standard_codings = ['utf-8', 'iso-8859-15', 'iso-8859-1',]
+standard_codings = ['utf-8', 'iso-8859-15', 'iso-8859-1', ]
 
 def execfilter(cmd, filename, codings=standard_codings):
     """ use cmd to get plaintext content of filename
