@@ -4,12 +4,12 @@
 
     Depends on: pdftotext command from xpdf-utils package
     
-    @copyright: 2006 by ThomasWaldmann MoinMoin:ThomasWaldmann
+    @copyright: 2006 MoinMoin:ThomasWaldmann
     @license: GNU GPL, see COPYING for details.
 """
 
-from MoinMoin import filter
+from MoinMoin.filter import execfilter
 
 def execute(indexobj, filename):
-    return filter.execfilter("pdftotext -enc UTF-8 %s -", filename)
+    return execfilter("pdftotext -enc UTF-8 '%s' -", filename)
 
