@@ -4,12 +4,12 @@
 
     Depends on: catdoc command from catdoc package
     
-    @copyright: 2006 by ThomasWaldmann MoinMoin:ThomasWaldmann
+    @copyright: 2006 MoinMoin:ThomasWaldmann
     @license: GNU GPL, see COPYING for details.
 """
 
-from MoinMoin import filter
+from MoinMoin.filter import execfilter
 
 def execute(indexobj, filename):
-    return filter.execfilter("catdoc %s", filename)
+    return execfilter("catdoc %s", filename)
 
