@@ -2,21 +2,22 @@
 """
     MoinMoin - "text/html+css" Formatter
 
-    @copyright: 2000 - 2004 by Jrgen Hermann <jh@web.de>
+    @copyright: 2000-2004 by Juergen Hermann <jh@web.de>
     @license: GNU GPL, see COPYING for details.
 """
 import os.path, re
-from sets import Set # TODO: when we require Python 2.4+ use the builtin 'set' type
-from MoinMoin.formatter.base import FormatterBase
-from MoinMoin import wikiutil, i18n, config
+
+from MoinMoin.formatter import FormatterBase
+from MoinMoin import wikiutil, i18n
 from MoinMoin.Page import Page
 from MoinMoin.action import AttachFile
+from MoinMoin.support.python_compatibility import set, rsplit
 
 line_anchors = True
 prettyprint = False
 
 # These are the HTML elements that we treat as block elements.
-_blocks = Set(['dd', 'div', 'dl', 'dt', 'form', 'h1', 'h2', 'h3', 'h4', 'h5', 'h6',
+_blocks = set(['dd', 'div', 'dl', 'dt', 'form', 'h1', 'h2', 'h3', 'h4', 'h5', 'h6',
                'hr', 'li', 'ol', 'p', 'pre', 'table', 'tbody', 'td', 'tfoot', 'th',
                'thead', 'tr', 'ul', 'blockquote', ])
 
@@ -26,30 +27,30 @@ _blocks = Set(['dd', 'div', 'dl', 'dt', 'form', 'h1', 'h2', 'h3', 'h4', 'h5', 'h
 # content, and also IE has a parsing bug with those two elements (only)
 # when they don't have a closing tag even if valid XHTML.
 
-_self_closing_tags = Set(['area', 'base', 'br', 'col', 'frame', 'hr', 'img', 'input',
-                          'isindex', 'link', 'meta', 'param'])
+_self_closing_tags = set(['area', 'base', 'br', 'col', 'frame', 'hr', 'img',
+                          'input', 'isindex', 'link', 'meta', 'param'])
 
 # We only open those tags and let the browser auto-close them:
-_auto_closing_tags = Set(['p'])
+_auto_closing_tags = set(['p'])
 
 # These are the elements which generally should cause an increase in the
 # indention level in the html souce code.
-_indenting_tags = Set(['ol', 'ul', 'dl', 'li', 'dt', 'dd', 'tr', 'td'])
+_indenting_tags = set(['ol', 'ul', 'dl', 'li', 'dt', 'dd', 'tr', 'td'])
 
 # These are the elements that discard any whitespace they contain as
 # immediate child nodes.
-_space_eating_tags = Set(['colgroup', 'dl', 'frameset', 'head', 'map' 'menu',
+_space_eating_tags = set(['colgroup', 'dl', 'frameset', 'head', 'map' 'menu',
                           'ol', 'optgroup', 'select', 'table', 'tbody', 'tfoot',
                           'thead', 'tr', 'ul'])
 
 # These are standard HTML attributes which are typically used without any
 # value; e.g., as boolean flags indicated by their presence.
-_html_attribute_boolflags = Set(['compact', 'disabled', 'ismap', 'nohref',
+_html_attribute_boolflags = set(['compact', 'disabled', 'ismap', 'nohref',
                                  'noresize', 'noshade', 'nowrap', 'readonly',
                                  'selected', 'wrap'])
 
 # These are all the standard HTML attributes that are allowed on any element.
-_common_attributes = Set(['accesskey', 'class', 'dir', 'disabled', 'id', 'lang',
+_common_attributes = set(['accesskey', 'class', 'dir', 'disabled', 'id', 'lang',
                           'style', 'tabindex', 'title'])
 
 
@@ -119,9 +120,9 @@ def rewrite_attribute_name(name, default_namespace='html'):
     if ns == 'html':
         # We have an HTML attribute, fix according to DTD
         if name == 'content_type': # MIME type such as in <a> and <link> elements
-            name =  'type'
+            name = 'type'
         elif name == 'content_id': # moin historical convention
-            name =  'id'
+            name = 'id'
         elif name in ('css_class', 'css'): # to avoid python word 'class'
             name = 'class'
         elif name.startswith('on'): # event handler hook
@@ -146,10 +147,10 @@ def extend_attribute_dictionary(attributedict, ns, name, value):
 
     key = ns, name
     if value is None:
-        if attributedict.has_key(key):
+        if key in attributedict:
             del attributedict[key]
     else:
-        if ns == 'html' and attributedict.has_key(key):
+        if ns == 'html' and key in attributedict:
             if name == 'class':
                 # CSS classes are appended by space-separated list
                 value = attributedict[key] + ' ' + value
@@ -173,7 +174,7 @@ class Formatter(FormatterBase):
     indentspace = ' '
 
     def __init__(self, request, **kw):
-        apply(FormatterBase.__init__, (self, request), kw)
+        FormatterBase.__init__(self, request, **kw)
 
         # inline tags stack. When an inline tag is called, it goes into
         # the stack. When a block element starts, all inline tags in
@@ -196,6 +197,7 @@ class Formatter(FormatterBase):
         self._is_included = kw.get('is_included', False)
         self.request = request
         self.cfg = request.cfg
+        self.no_magic = kw.get('no_magic', False) # disabled tag auto closing
 
         if not hasattr(request, '_fmt_hd_counters'):
             request._fmt_hd_counters = []
@@ -226,7 +228,7 @@ class Formatter(FormatterBase):
                 return {}
 
         #attr = {'xml:lang': lang, 'lang': lang, 'dir': i18n.getDirection(lang),}
-        attr = {'lang': lang, 'dir': i18n.getDirection(lang),}
+        attr = {'lang': lang, 'dir': i18n.getDirection(lang), }
         return attr
 
     def _formatAttributes(self, attr=None, allowed_attrs=None, **kw):
@@ -268,21 +270,21 @@ class Formatter(FormatterBase):
                 extend_attribute_dictionary(attributes, a_ns, a_name, v)
 
         # Add title attribute if missing, but it has an alt.
-        if attributes.has_key(('html', 'alt')) and not attributes.has_key(('html', 'title')):
+        if ('html', 'alt') in attributes and ('html', 'title') not in attributes:
             attributes[('html', 'title')] = attributes[('html', 'alt')]
 
         # Force both lang and xml:lang to be present and identical if
         # either exists.  The lang takes precedence over xml:lang if
         # both exist.
-        #if attributes.has_key(('html', 'lang')):
+        #if ('html', 'lang') in attributes:
         #    attributes[('xml', 'lang')] = attributes[('html', 'lang')]
-        #elif attributes.has_key(('xml', 'lang')):
+        #elif ('xml', 'lang') in attributes:
         #    attributes[('html', 'lang')] = attributes[('xml', 'lang')]
 
         # Check all the HTML attributes to see if they are known and
         # allowed.  Ignore attributes if in non-HTML namespaces.
         if allowed_attrs:
-            for name in [key[1] for key in attributes.keys() if key[0] == 'html']:
+            for name in [key[1] for key in attributes if key[0] == 'html']:
                 if name in _common_attributes or name in allowed_attrs:
                     pass
                 elif name.startswith('on'):
@@ -335,12 +337,12 @@ class Formatter(FormatterBase):
         if tag in _blocks:
             # Block elements
             result = []
-            
+
             # Add language attributes, but let caller overide the default
             attributes = self._langAttr()
             if attr:
                 attributes.update(attr)
-            
+
             # Format
             attributes = self._formatAttributes(attributes, allowed_attrs=allowed_attrs, **kw)
             result.append('<%s%s%s>' % (tag, attributes, is_self_closing))
@@ -372,7 +374,7 @@ class Formatter(FormatterBase):
         @rtype: string
         @return: closing tag as a string
         """
-        if tag in _self_closing_tags or tag in _auto_closing_tags:
+        if tag in _self_closing_tags or (tag in _auto_closing_tags and not self.no_magic):
             # This tag was already closed
             tagstr = ''
         elif tag in _blocks:
@@ -388,7 +390,7 @@ class Formatter(FormatterBase):
             if newline:
                 result.append(self._newline())
             result.append('</%s>' % (tag))
-            tagstr = ''.join(result)            
+            tagstr = ''.join(result)
         else:
             # Inline elements 
             # Pull from stack, ignore order, that is not our problem.
@@ -433,7 +435,7 @@ class Formatter(FormatterBase):
         if newline:
             result.append('\n')
         return ''.join(result)
-        
+
     def endContent(self, newline=True):
         """ Close page content div.
 
@@ -455,7 +457,7 @@ class Formatter(FormatterBase):
         result = []
         result.append(self.anchordef(aid))
         result.append(self._close('div', newline=newline))
-        return ''.join(result) 
+        return ''.join(result)
 
     def lang(self, on, lang_name):
         """ Insert text with specific lang and direction.
@@ -472,10 +474,10 @@ class Formatter(FormatterBase):
             return self._close(tag)
 
         # Direction did not change, no need for span
-        return ''            
-                
+        return ''
+
     # Links ##############################################################
-    
+
     def pagelink(self, on, pagename='', page=None, **kw):
         """ Link to a page.
 
@@ -484,9 +486,11 @@ class Formatter(FormatterBase):
 
             See wikiutil.link_tag() for possible keyword parameters.
         """
-        apply(FormatterBase.pagelink, (self, on, pagename, page), kw)
+        FormatterBase.pagelink(self, on, pagename, page, **kw)
+        if 'generated' in kw:
+            del kw['generated']
         if page is None:
-            page = Page(self.request, pagename, formatter=self);
+            page = Page(self.request, pagename, formatter=self)
         if self.request.user.show_nonexist_qm and on and not page.exists():
             self.pagelink_preclosed = True
             return (page.link_to(self.request, on=1, **kw) +
@@ -502,28 +506,30 @@ class Formatter(FormatterBase):
         """
         @keyword title: override using the interwiki wikiname as title
         """
-        wikitag, wikiurl, wikitail, wikitag_bad = wikiutil.resolve_wiki(self.request, '%s:%s' % (interwiki, pagename))
+        querystr = kw.get('querystr', {})
+        wikitag, wikiurl, wikitail, wikitag_bad = wikiutil.resolve_interwiki(self.request, interwiki, pagename)
         wikiurl = wikiutil.mapURL(self.request, wikiurl)
         if wikitag == 'Self': # for own wiki, do simple links
-            if on:
-                if wikitail.find('#') > -1:
-                    wikitail, kw['anchor'] = wikitail.split('#', 1)
-                wikitail = wikiutil.url_unquote(wikitail)
-                try: # XXX this is the only place where we access self.page - do we need it? Crashes silently on actions!
-                    return apply(self.pagelink, (on, wikiutil.AbsPageName(self.request, self.page.page_name, wikitail)), kw)
-                except:
-                    return apply(self.pagelink, (on, wikitail), kw)
-            else:
-                return self.pagelink(0)
+            if '#' in wikitail:
+                wikitail, kw['anchor'] = rsplit(wikitail, '#', 1)
+            wikitail = wikiutil.url_unquote(wikitail)
+            try: # XXX this is the only place where we access self.page - do we need it? Crashes silently on actions!
+                pagename = wikiutil.AbsPageName(self.page.page_name, wikitail)
+            except:
+                pagename = wikitail
+            return self.pagelink(on, pagename, **kw)
         else: # return InterWiki hyperlink
             if on:
                 href = wikiutil.join_wiki(wikiurl, wikitail)
+                if querystr:
+                    separator = ('?', '&')['?' in href]
+                    href = '%s%s%s' % (href, separator, wikiutil.makeQueryString(querystr))
                 if wikitag_bad:
                     html_class = 'badinterwiki'
                 else:
                     html_class = 'interwiki'
                 title = kw.get('title', wikitag)
-                return self.url(1, href, title=title, do_escape=1, css=html_class) # interwiki links with umlauts
+                return self.url(1, href, title=title, css=html_class) # interwiki links with umlauts
             else:
                 return self.url(0)
 
@@ -534,7 +540,7 @@ class Formatter(FormatterBase):
         Call once with on=1 to start the link, and again with on=0
         to end it (no other arguments are needed when on==0).
 
-        do_escape: XXX doesn't work yet
+        do_escape: filters url through wikiutil.escape
 
         Keyword params:
             url - the URL to link to; will go through Wiki URL mapping.
@@ -553,24 +559,24 @@ class Formatter(FormatterBase):
             attrs = self._langAttr()
 
             # Handle the URL mapping
-            if url is None and kw.has_key('href'):
+            if url is None and 'href' in kw:
                 url = kw['href']
                 del kw['href']
             if url is not None:
                 url = wikiutil.mapURL(self.request, url)
-                # TODO just calling url_quote does not work, as it will also quote "http:" to "http%xx" X)
-                if 0: # do_escape: # protocol and server part must not get quoted, path should get quoted
-                    url = wikiutil.url_quote(url)
+                if do_escape:
+                    url = wikiutil.escape(url)
                 attrs['href'] = url
 
             if css:
                 attrs['class'] = css
-            
+
             markup = self._open('a', attr=attrs, **kw)
         else:
             markup = self._close('a')
         return markup
 
+
     def anchordef(self, id):
         """Inserts an invisible element used as a link target.
 
@@ -607,7 +613,7 @@ class Formatter(FormatterBase):
         attrs = self._langAttr()
         if name:
             attrs['href'] = '#%s' % name
-        if kw.has_key('href'):
+        if 'href' in kw:
             del kw['href']
         if on:
             str = self._open('a', attr=attrs, **kw)
@@ -623,42 +629,63 @@ class Formatter(FormatterBase):
 
     # Attachments ######################################################
 
-    def attachment_link(self, url, text, **kw):
+    def attachment_link(self, on, url=None, **kw):
+        """ Link to an attachment.
+
+            @param on: 1/True=start link, 0/False=end link
+            @param url: filename.ext or PageName/filename.ext
+        """
+        assert on in (0, 1, False, True) # make sure we get called the new way, not like the 1.5 api was
         _ = self.request.getText
-        pagename, filename = AttachFile.absoluteName(url, self.page.page_name)
-        fname = wikiutil.taintfilename(filename)
-        fpath = AttachFile.getFilename(self.request, pagename, fname)
-        if not os.path.exists(fpath):
-            linktext = _('Upload new attachment "%(filename)s"')
-            return wikiutil.link_tag(
-                self.request,
-                ('%s?action=AttachFile&rename=%s' %
-                 (wikiutil.quoteWikinameURL(pagename),
-                  wikiutil.url_quote_plus(fname))),
-                linktext % {'filename': self.text(fname)})
-        target = AttachFile.getAttachUrl(pagename, filename, self.request)
-        return (self.url(1, target, css='attachment', title="attachment:%s" % url) +
-                self.text(text) +
-                self.url(0))
-    
+        querystr = kw.get('querystr', {})
+        assert isinstance(querystr, dict) # new in 1.6, only support dicts
+        if 'do' not in querystr:
+            querystr['do'] = 'view'
+        if on:
+            pagename, filename = AttachFile.absoluteName(url, self.page.page_name)
+            #self.request.log("attachment_link: url %s pagename %s filename %s" % (url, pagename, filename))
+            fname = wikiutil.taintfilename(filename)
+            if AttachFile.exists(self.request, pagename, fname):
+                target = AttachFile.getAttachUrl(pagename, fname, self.request, do=querystr['do'])
+                title = "attachment:%s" % url
+                css = 'attachment'
+            else:
+                target = AttachFile.getAttachUploadUrl(pagename, fname, self.request)
+                title = _('Upload new attachment "%(filename)s"', formatted=False) % {'filename': wikiutil.escape(fname)}
+                css = 'attachment nonexistent'
+            return self.url(on, target, css=css, title=title)
+        else:
+            return self.url(on)
+
     def attachment_image(self, url, **kw):
         _ = self.request.getText
         pagename, filename = AttachFile.absoluteName(url, self.page.page_name)
         fname = wikiutil.taintfilename(filename)
-        fpath = AttachFile.getFilename(self.request, pagename, fname)
-        if not os.path.exists(fpath):
-            linktext = _('Upload new attachment "%(filename)s"')
+        exists = AttachFile.exists(self.request, pagename, fname)
+        if exists:
+            kw['css'] = 'attachment'
+            kw['src'] = AttachFile.getAttachUrl(pagename, filename, self.request, addts=1)
+            title = _('Inlined image: %(url)s', formatted=False) % {'url': self.text(url)}
+            if not 'title' in kw:
+                kw['title'] = title
+            # alt is required for images:
+            if not 'alt' in kw:
+                kw['alt'] = kw['title']
+            return self.image(**kw)
+        else:
+            title = _('Upload new attachment "%(filename)s"', formatted=False) % {
+                      'filename': wikiutil.escape(fname)}
+            img = self.icon('attachimg')
+            css = 'nonexistent'
             return wikiutil.link_tag(
                 self.request,
                 ('%s?action=AttachFile&rename=%s' %
                  (wikiutil.quoteWikinameURL(pagename),
                   wikiutil.url_quote_plus(fname))),
-                linktext % {'filename': self.text(fname)})
-        return self.image(
-            title="attachment:%s" % url,
-            src=AttachFile.getAttachUrl(pagename, filename, self.request, addts=1),
-            css="attachment")
-    
+                img,
+                title=title,
+                css_class=css)
+
     def attachment_drawing(self, url, text, **kw):
         _ = self.request.getText
         pagename, filename = AttachFile.absoluteName(url, self.page.page_name)
@@ -667,17 +694,17 @@ class Formatter(FormatterBase):
         fname = fname + u".png"
         filename = filename + u".png"
         # fallback for old gif drawings (1.1 -> 1.2)
-        fpath = AttachFile.getFilename(self.request, pagename, fname)
-        if not os.path.exists(fpath):
+        exists = AttachFile.exists(self.request, pagename, fname)
+        if not exists:
             gfname = fname[:-4] + u".gif"
             gfilename = filename[:-4] + u".gif"
-            gfpath = AttachFile.getFilename(self.request, pagename, gfname)
-            if os.path.exists(gfpath):
-                fname, filename, fpath = gfname, gfilename, gfpath
+            exists = AttachFile.exists(self.request, pagename, gfname)
+            if exists:
+                fname, filename = gfname, gfilename
 
         # check whether attachment exists, possibly point to upload form
-        if not os.path.exists(fpath):
-            linktext = _('Create new drawing "%(filename)s"')
+        if not exists:
+            linktext = _('Create new drawing "%(filename)s (opens in new window)"', formatted=False)
             return wikiutil.link_tag(
                 self.request,
                 ('%s?action=AttachFile&rename=%s%s' %
@@ -694,8 +721,7 @@ class Formatter(FormatterBase):
 
         # check for map file
         if os.path.exists(mappath):
-            # we have a image map. inline it and add a map ref
-            # to the img tag
+            # we have a image map. inline it and add a map ref to the img tag
             try:
                 map = file(mappath, 'r').read()
             except IOError:
@@ -703,35 +729,34 @@ class Formatter(FormatterBase):
             except OSError:
                 pass
             else:
-                mapid = 'ImageMapOf'+drawing
+                mapid = 'ImageMapOf' + drawing
                 # replace MAPNAME
                 map = map.replace('%MAPNAME%', mapid)
                 # add alt and title tags to areas
                 map = re.sub('href\s*=\s*"((?!%TWIKIDRAW%).+?)"', r'href="\1" alt="\1" title="\1"', map)
                 # add in edit links plus alt and title attributes
-                map = map.replace('%TWIKIDRAW%"', edit_link + '" alt="' + _('Edit drawing %(filename)s') % {'filename': self.text(fname)} + '" title="' + _('Edit drawing %(filename)s') % {'filename': self.text(fname)} + '"')
+                alt = title = _('Edit drawing %(filename)s (opens in new window)', formatted=False) % {'filename': self.text(fname)}
+                map = map.replace('%TWIKIDRAW%"', '%s" alt="%s" title="%s"' % (edit_link, alt, title))
                 # unxml, because 4.01 concrete will not validate />
                 map = map.replace('/>', '>')
+                alt = title = _('Clickable drawing: %(filename)s', formatted=False) % {'filename': self.text(fname)}
                 return (map + self.image(
-                    alt=drawing,
-                    src=AttachFile.getAttachUrl(
-                    pagename, filename, self.request,
-                    addts=1),
+                    alt=alt,
+                    title=title,
+                    src=AttachFile.getAttachUrl(pagename, filename, self.request, addts=1),
                     usemap='#'+mapid, css="drawing"))
         else:
+            alt = title = _('Edit drawing %(filename)s (opens in new window)', formatted=False) % {'filename': self.text(fname)}
             return wikiutil.link_tag(self.request,
                                      edit_link,
-                                     self.image(alt=url,
+                                     self.image(alt=alt,
+                                                title=title,
                                                 src=AttachFile.getAttachUrl(pagename, filename, self.request, addts=1), css="drawing"),
-                                     title="%s" % (_('Edit drawing %(filename)s') % {'filename': self.text(fname)}))
-        
-    
-    # def attachment_inlined(self, url, text, **kw):
-    # moved to MoinMoin/formatter/base.py
+                                     title=title)
 
 
     # Text ##############################################################
-    
+
     def _text(self, text):
         text = wikiutil.escape(text)
         if self._in_code:
@@ -739,7 +764,7 @@ class Formatter(FormatterBase):
         return text
 
     # Inline ###########################################################
-        
+
     def strong(self, on, **kw):
         """Creates an HTML <strong> element.
 
@@ -830,11 +855,11 @@ class Formatter(FormatterBase):
         """
         tag = 'tt'
         # Maybe we don't need this, because we have tt will be in inlineStack.
-        self._in_code = on        
+        self._in_code = on
         if on:
             return self._open(tag, allowed_attrs=[], **kw)
         return self._close(tag)
-        
+
     def small(self, on, **kw):
         """Creates a <small> element for smaller font.
 
@@ -871,7 +896,7 @@ class Formatter(FormatterBase):
         if on:
             return self._open(tag, newline=1, **kw)
         return self._close(tag)
-                
+
     # Use by code area
     _toggleLineNumbersScript = """
 <script type="text/javascript">
@@ -924,7 +949,7 @@ function togglenumber(did, nstart, nstep) {
 }
 </script>
 """
-    
+
     def code_area(self, on, code_id, code_type='code', show=0, start=-1, step=-1):
         """Creates a formatted code region, with line numbering.
 
@@ -965,7 +990,7 @@ document.write('<a href="#" onclick="return togglenumber(\'%s\', %d, %d);" \
                 class="codenumbers">%s<\/a>');
 </script>
 ''' % (self._code_area_state[0], self._code_area_state[2], self._code_area_state[3],
-       _("Toggle line numbers"))
+       _("Toggle line numbers", formatted=False))
                 res.append(toggleLineNumbersLink)
 
             # Open pre - using left to right always!
@@ -1001,7 +1026,7 @@ document.write('<a href="#" onclick="return togglenumber(\'%s\', %d, %d);" \
         return ['<span class="%s">' % tok_type, '</span>'][not on]
 
     # Paragraphs, Lines, Rules ###########################################
-    
+
     def _indent_spaces(self):
         """Returns space(s) for indenting the html source so list nesting is easy to read.
 
@@ -1027,7 +1052,7 @@ document.write('<a href="#" onclick="return togglenumber(\'%s\', %d, %d);" \
         if self._in_code_area:
             preformatted = 1
         return ['\n', '<br />\n'][not preformatted] + self._indent_spaces()
-        
+
     def paragraph(self, on, **kw):
         """Creates a paragraph with a <p> element.
         
@@ -1055,16 +1080,13 @@ document.write('<a href="#" onclick="return togglenumber(\'%s\', %d, %d);" \
             # Add hr class: hr1 - hr6
             return self._open('hr', newline=1, attr={'class': 'hr%d' % size}, **kw)
         return self._open('hr', newline=1, **kw)
-                
+
+    # Images / Transclusion ##############################################
+
     def icon(self, type):
         return self.request.theme.make_icon(type)
 
-    def smiley(self, text):
-        w, h, b, img = config.smileys[text.strip()]
-        href = img
-        if not href.startswith('/'):
-            href = self.request.theme.img_url(img)
-        return self.image(src=href, alt=text, width=str(w), height=str(h))
+    smiley = icon
 
     def image(self, src=None, **kw):
         """Creates an inline image with an <img> element.
@@ -1075,6 +1097,24 @@ document.write('<a href="#" onclick="return togglenumber(\'%s\', %d, %d);" \
             kw['src'] = src
         return self._open('img', **kw)
 
+    def transclusion(self, on, **kw):
+        """Transcludes (includes/embeds) another object."""
+        if on:
+            return self._open('object',
+                              allowed_attrs=['archive', 'classid', 'codebase',
+                                             'codetype', 'data', 'declare',
+                                             'height', 'name', 'standby',
+                                             'type', 'width', ],
+                              **kw)
+        else:
+            return self._close('object')
+
+    def transclusion_param(self, **kw):
+        """Give a parameter to a transcluded object."""
+        return self._open('param',
+                          allowed_attrs=['name', 'type', 'value', 'valuetype', ],
+                          **kw)
+
     # Lists ##############################################################
 
     def number_list(self, on, type=None, start=None, **kw):
@@ -1100,7 +1140,7 @@ document.write('<a href="#" onclick="return togglenumber(\'%s\', %d, %d);" \
         else:
             tagstr = self._close(tag, newline=1)
         return tagstr
-    
+
     def bullet_list(self, on, **kw):
         """Creates an HTML ordered list, <ul> element.
 
@@ -1126,7 +1166,7 @@ document.write('<a href="#" onclick="return togglenumber(\'%s\', %d, %d);" \
         """
         tag = 'li'
         if on:
-            tagstr =  self._open(tag, newline=1, **kw)
+            tagstr = self._open(tag, newline=1, **kw)
         else:
             tagstr = self._close(tag, newline=1)
         return tagstr
@@ -1189,12 +1229,12 @@ document.write('<a href="#" onclick="return togglenumber(\'%s\', %d, %d);" \
                 # explicit base level for section number display
                 self._show_section_numbers = int(numbering)
 
-        heading_depth = depth # + 1
+        heading_depth = depth
 
         # closing tag, with empty line after, to make source more readable
         if not on:
             return self._close('h%d' % heading_depth) + '\n'
-            
+
         # create section number
         number = ''
         if self._show_section_numbers:
@@ -1203,27 +1243,20 @@ document.write('<a href="#" onclick="return togglenumber(\'%s\', %d, %d);" \
             while len(self.request._fmt_hd_counters) < count_depth:
                 self.request._fmt_hd_counters.append(0)
             self.request._fmt_hd_counters[-1] = self.request._fmt_hd_counters[-1] + 1
-            number = '.'.join(map(str, self.request._fmt_hd_counters[self._show_section_numbers-1:]))
+            number = '.'.join([str(x) for x in self.request._fmt_hd_counters[self._show_section_numbers-1:]])
             if number: number += ". "
 
         # Add space before heading, easier to check source code
         result = '\n' + self._open('h%d' % heading_depth, **kw)
 
-        # TODO: convert this to readable code
         if self.request.user.show_topbottom:
-            # TODO change top/bottom refs to content-specific top/bottom refs?
-            result = ("%s%s%s%s%s%s%s%s" %
-                      (result,
-                       kw.get('icons', ''),
-                       self.url(1, "#bottom", do_escape=0),
-                       self.icon('bottom'),
-                       self.url(0),
-                       self.url(1, "#top", do_escape=0),
-                       self.icon('top'),
-                       self.url(0)))
-        return "%s%s%s" % (result, kw.get('icons', ''), number)
+            result += "%s%s%s%s%s%s" % (
+                       self.anchorlink(1, "bottom"), self.icon('bottom'), self.anchorlink(0),
+                       self.anchorlink(1, "top"), self.icon('top'), self.anchorlink(0))
+
+        return "%s%s" % (result, number)
+
 
-    
     # Tables #############################################################
 
     _allowed_table_attrs = {
@@ -1312,8 +1345,8 @@ document.write('<a href="#" onclick="return togglenumber(\'%s\', %d, %d);" \
             result.append(self._close('table'))
             result.append(self._close('div'))
 
-        return ''.join(result)    
-    
+        return ''.join(result)
+
     def table_row(self, on, attrs=None, **kw):
         tag = 'tr'
         if on:
@@ -1325,7 +1358,7 @@ document.write('<a href="#" onclick="return togglenumber(\'%s\', %d, %d);" \
                              allowed_attrs=self._allowed_table_attrs['row'],
                              **kw)
         return self._close(tag) + '\n'
-    
+
     def table_cell(self, on, attrs=None, **kw):
         tag = 'td'
         if on:
@@ -1358,17 +1391,36 @@ document.write('<a href="#" onclick="return togglenumber(\'%s\', %d, %d);" \
         if on:
             return self._open(tag, attr={'class': 'message'}, **kw)
         return self._close(tag)
-    
+
     def div(self, on, **kw):
+        css_class = kw.get('css_class')
+        # the display of comment class divs depends on a user setting:
+        if css_class and 'comment' in css_class.split():
+            style = kw.get('style')
+            display = self.request.user.show_comments and "display:''" or "display:none"
+            if not style:
+                style = display
+            else:
+                style += "; %s" % display
+            kw['style'] = style
         tag = 'div'
         if on:
             return self._open(tag, **kw)
         return self._close(tag)
 
     def span(self, on, **kw):
+        css_class = kw.get('css_class')
+        # the display of comment class spans depends on a user setting:
+        if css_class and 'comment' in css_class.split():
+            style = kw.get('style')
+            display = self.request.user.show_comments and "display:''" or "display:none"
+            if not style:
+                style = display
+            else:
+                style += "; %s" % display
+            kw['style'] = style
         tag = 'span'
         if on:
             return self._open(tag, **kw)
         return self._close(tag)
-    
 
