@@ -2,11 +2,11 @@
 """
     MoinMoin - "text/plain" Formatter
 
-    @copyright: 2000, 2001, 2002 by Jrgen Hermann <jh@web.de>
+    @copyright: 2000-2002 Juergen Hermann <jh@web.de>
     @license: GNU GPL, see COPYING for details.
 """
 
-from MoinMoin.formatter.base import FormatterBase
+from MoinMoin.formatter import FormatterBase
 
 class Formatter(FormatterBase):
     """
@@ -16,7 +16,7 @@ class Formatter(FormatterBase):
     hardspace = u' '
 
     def __init__(self, request, **kw):
-        apply(FormatterBase.__init__, (self, request), kw)
+        FormatterBase.__init__(self, request, **kw)
         self._in_code_area = 0
         self._in_code_line = 0
         self._code_area_state = [0, -1, -1, 0]
@@ -36,7 +36,7 @@ class Formatter(FormatterBase):
         return (u'\n\n*** ', u' ***\n\n')[not on]
 
     def pagelink(self, on, pagename='', page=None, **kw):
-        apply(FormatterBase.pagelink, (self, on, pagename, page), kw)
+        FormatterBase.pagelink(self, on, pagename, page, **kw)
         return (u">>", u"<<") [not on]
 
     def interwikilink(self, on, interwiki='', pagename='', **kw):
@@ -53,7 +53,7 @@ class Formatter(FormatterBase):
                 self._url = None
                 self._text = None
                 return u' [%s]' % (self._url)
-            
+
     def url(self, on, url='', css=None, **kw):
         if on:
             self._url = url
@@ -69,19 +69,22 @@ class Formatter(FormatterBase):
                 self._text = None
                 return u' [%s]' % (self._url)
 
-    def attachment_link(self, url, text, **kw):
-        return "[%s]" % text
+    def attachment_link(self, on, url=None, **kw):
+        if on:
+            return "["
+        else:
+            return "]"
 
     def attachment_image(self, url, **kw):
         title = ''
         for a in (u'title', u'html__title', u'alt', u'html_alt'):
-            if kw.has_key(a):
+            if a in kw:
                 title = ':' + kw[a]
         return "[image:%s%s]" % (url, title)
 
     def attachment_drawing(self, url, text, **kw):
         return "[drawing:%s]" % text
-    
+
     def text(self, text, **kw):
         self._did_para = 0
         if self._text is not None:
@@ -129,7 +132,7 @@ class Formatter(FormatterBase):
             if self._in_list > 0:
                 self._in_list += 1
                 self._did_para = 1
-                return ' %d. ' % (self._in_list-1,)
+                return ' %d. ' % (self._in_list-1, )
             elif self._in_list < 0:
                 self._did_para = 1
                 return u' * '
@@ -138,7 +141,7 @@ class Formatter(FormatterBase):
         else:
             self._did_para = 1
             return u'\n'
-        
+
     def sup(self, on, **kw):
         return u'^'
 
@@ -211,7 +214,7 @@ class Formatter(FormatterBase):
             self._text = []
             return '\n\n'
         else:
-            result =  u'\n%s\n\n' % (u'=' * len("".join(self._text)))
+            result = u'\n%s\n\n' % (u'=' * len("".join(self._text)))
             self._text = None
             return result
 
@@ -243,10 +246,16 @@ class Formatter(FormatterBase):
 
     def image(self, src=None, **kw):
         for a in (u'title', u'html__title', u'alt', u'html_alt'):
-            if kw.has_key(a):
+            if a in kw:
                 return kw[a]
         return u''
 
+    def transclusion(self, on, **kw):
+        return u''
+
+    def transclusion_param(self, **kw):
+        return u''
+
     def lang(self, on, lang_name):
         return ''
 
