@@ -4,13 +4,14 @@
 
     Compiles pages to executable python code.
 
-    @copyright: 2000-2004 by Jrgen Hermann <jh@web.de>
+    @copyright: 2000-2004 by Juergen Hermann <jh@web.de>
     @license: GNU GPL, see COPYING for details.
 """
 
 import time
 from MoinMoin import wikiutil
 
+
 class Formatter:
     """
         Inserts '<<<>>>' into the page and adds python code to
@@ -21,7 +22,7 @@ class Formatter:
     """
 
     defaultDependencies = ["time"]
-    
+
     def __init__(self, request, static=[], formatter=None, **kw):
         if formatter:
             self.formatter = formatter
@@ -71,7 +72,7 @@ if moincode_timestamp > %d or cfg_mtime is None or cfg_mtime > %d:
             i += 1
         source.append(self.text_cmd_end)
         source.append(self.__adjust_formatter_state())
-        
+
         self.code_fragments = [] # clear code fragments to make
                                  # this object reusable
         return "".join(source)
@@ -87,6 +88,10 @@ if moincode_timestamp > %d or cfg_mtime is None or cfg_mtime > %d:
         self.code_fragments.append(call)
         return '<<<>>>'
 
+    def __insert_fmt_call(self, function, *args, **kw):
+        return self.__insert_code('request.write(%s.%s(*%r, **%r))' % (
+            self.__formatter, function, args, kw))
+
     def __is_static(self, dependencies):
         for dep in dependencies:
             if dep not in self.static:
@@ -99,7 +104,7 @@ if moincode_timestamp > %d or cfg_mtime is None or cfg_mtime > %d:
             self.__lang = self.request.current_lang
             return 'request.current_lang = %r\n' % self.__lang
         return ''
-        
+
     def __adjust_formatter_state(self):
         result = self.__adjust_language_state()
         if self.__in_p != self.formatter.in_p:
@@ -109,21 +114,11 @@ if moincode_timestamp > %d or cfg_mtime is None or cfg_mtime > %d:
         if self.__in_pre != self.formatter.in_pre:
             result = "%s%s.in_pre = %r\n" % (result, self.__formatter,
                                            self.formatter.in_pre)
-            self.__in_pre = self.formatter.in_pre        
+            self.__in_pre = self.formatter.in_pre
         return result
-    
-    def dynamic_content(self, parser, callback, arg_list=[], arg_dict={},
-                            returns_content=1):
-        adjust = self.__adjust_formatter_state()
-        if returns_content:
-            return self.__insert_code('%srequest.write(%s.%s(*%r,**%r))' %
-                        (adjust, self.__parser, callback, arg_list, arg_dict))
-        else:
-            return self.__insert_code('%s%s.%s(*%r,**%r)' %
-                        (adjust, self.__parser, callback, arg_list, arg_dict))
 
     # Public methods ---------------------------------------------------
-        
+
     def pagelink(self, on, pagename='', page=None, **kw):
         if on:
             return self.__insert_code('page=Page(request, %r, formatter=%s);'
@@ -134,33 +129,25 @@ if moincode_timestamp > %d or cfg_mtime is None or cfg_mtime > %d:
             return self.__insert_code('request.write(%s.pagelink(%r, page=page, **%r))' %
                                       (self.__formatter, on, kw))
 
-    def attachment_link(self, url, text, **kw):
-        return self.__insert_code(
-            'request.write(%s.attachment_link(%r, %r, **%r))' %
-            (self.__formatter, url, text, kw))
+    def attachment_link(self, on, url=None, **kw):
+        return self.__insert_fmt_call('attachment_link', on, url, **kw)
 
     def attachment_image(self, url, **kw):
-        return self.__insert_code(
-            'request.write(%s.attachment_image(%r, **%r))' %
-            (self.__formatter, url, kw))
-    
-    def attachment_drawing(self, url, text, **kw):
-        return self.__insert_code(
-            'request.write(%s.attachment_drawing(%r, %r, **%r))' %
-            (self.__formatter, url, text, kw))
-    
-    def attachment_inlined(self, url, text, **kw):
-        return self.__insert_code(
-            'request.write(%s.attachment_inlined(%r, %r, **%r))' %
-            (self.__formatter, url, text, kw))
+        return self.__insert_fmt_call('attachment_image', url, **kw)
 
-    def heading(self, on, depth, **kw):        
+    def attachment_drawing(self, url, text, **kw):
+        return self.__insert_fmt_call('attachment_drawing', url, text, **kw)
+
+    def attachment_inlined(self, url, text, **kw):
+        return self.__insert_fmt_call('attachment_inlined', url, text, **kw)
+
+    def heading(self, on, depth, **kw):
         if on:
             code = [
                 self.__adjust_language_state(),
                 'request.write(%s.heading(%r, %r, **%r))' % (self.__formatter,
                                                              on, depth, kw),
-                ]     
+                ]
             return self.__insert_code(''.join(code))
         else:
             return self.formatter.heading(on, depth, **kw)
@@ -169,34 +156,47 @@ if moincode_timestamp > %d or cfg_mtime is None or cfg_mtime > %d:
         if self.__is_static(['user']):
             return self.formatter.icon(type)
         else:
-            return self.__insert_code('request.write(%s.icon(%r))' %
-                                      (self.__formatter, type))
+            return self.__insert_fmt_call('icon', type)
 
-    def macro(self, macro_obj, name, args):
+    smiley = icon
+
+    def span(self, on, **kw):
+        if on and 'comment' in kw.get('css_class', '').split():
+            return self.__insert_fmt_call('span', on, **kw)
+        else:
+            return self.formatter.span(on, **kw)
+
+    def div(self, on, **kw):
+        if on and 'comment' in kw.get('css_class', '').split():
+            return self.__insert_fmt_call('div', on, **kw)
+        else:
+            return self.formatter.div(on, **kw)
+
+    def macro(self, macro_obj, name, args, markup=None):
         if self.__is_static(macro_obj.get_dependencies(name)):
+            # XXX: why is this necessary??
+            macro_obj.formatter = self
             return macro_obj.execute(name, args)
         else:
             return self.__insert_code(
-                '%srequest.write(%s.macro(macro_obj, %r, %r))' %
+                '%srequest.write(%s.macro(macro_obj, %r, %r, %r))' %
                 (self.__adjust_formatter_state(),
-                 self.__formatter, name, args))
-            
-    def processor(self, processor_name, lines, is_parser=0):
-        """ processor_name MUST be valid!
-        prints out the result insted of returning it!
+                 self.__formatter, name, args, markup))
+
+    def parser(self, parser_name, lines):
+        """ parser_name MUST be valid!
+            prints out the result instead of returning it!
         """
-        type = ["processor", "parser"][is_parser]
         try:
-            Dependencies = wikiutil.importPlugin(self.request.cfg, type,
-                                                 processor_name,
-                                                 "Dependencies")
-        except wikiutil.PluginAttributeError:
+            Dependencies = wikiutil.searchAndImportPlugin(self.request.cfg, "parser", parser_name, "Dependencies")
+        except (wikiutil.PluginMissingError, wikiutil.PluginAttributeError):
             Dependencies = self.defaultDependencies
+
         if self.__is_static(Dependencies):
-            return self.formatter.processor(processor_name, lines, is_parser)
+            return self.formatter.parser(parser_name, lines)
         else:
-            return self.__insert_code('%s%s.processor(%r, %r, %r)' %
+            return self.__insert_code('%s%s.parser(%r, %r)' %
                                       (self.__adjust_formatter_state(),
                                        self.__formatter,
-                                       processor_name, lines, is_parser))
+                                       parser_name, lines))
 
