@@ -4,7 +4,7 @@
 
     Optional integer argument: maximal depth of listing.
 
-    @copyright: 2000, 2001, 2002 by Jrgen Hermann <jh@web.de>
+    @copyright: 2000-2002 Juergen Hermann <jh@web.de>
     @license: GNU GPL, see COPYING for details.
 """
 
@@ -39,12 +39,12 @@ class TableOfContents:
     def __init__(self, macro, args):
         self.macro = macro
         self._ = self.macro.request.getText
-        
-        self.inc_re = re.compile(r"^\[\[Include\((.*)\)\]\]")
+
+        self.inc_re = re.compile(r"^\<\<Include\((.*)\)\>\>")
         self.arg_re = re.compile(_args_re_pattern)
         self.head_re = re.compile(_title_re) # single lines only
         self.pre_re = re.compile(r'\{\{\{.+?\}\}\}', re.S)
-        
+
         self.result = []
         self.baseindent = 0
         self.indent = 0
@@ -67,19 +67,19 @@ class TableOfContents:
         if self.include_macro is None:
             self.include_macro = wikiutil.importPlugin(self.macro.request.cfg,
                                                        'macro', "Include")
-        return self.pre_re.sub('',apply(self.include_macro, args, kwargs)).split('\n')
+        return self.pre_re.sub('', self.include_macro(*args, **kwargs)).split('\n')
 
     def run(self):
         _ = self._
         self.result.append(self.macro.formatter.div(1, css_class="table-of-contents"))
         self.result.append(self.macro.formatter.paragraph(1, css_class="table-of-contents-heading"))
-        self.result.append(self.macro.formatter.escapedText(_('Contents')))
+        self.result.append(self.macro.formatter.escapedText(_('Contents', formatted=False)))
         self.result.append(self.macro.formatter.paragraph(0))
 
-        self.process_lines(self.pre_re.sub('',self.macro.parser.raw).split('\n'),
+        self.process_lines(self.pre_re.sub('', self.macro.parser.raw).split('\n'),
                            self.macro.formatter.page.page_name)
         # Close pending lists
-        for i in range(self.baseindent, self.indent):
+        for dummy in range(self.baseindent, self.indent):
             self.result.append(self.macro.formatter.listitem(0))
             self.result.append(self.macro.formatter.number_list(0))
         self.result.append(self.macro.formatter.div(0))
@@ -91,7 +91,7 @@ class TableOfContents:
             self.lineno = self.lineno + 1
             match = self.inc_re.match(line)
             if match:
-                # this is an [[Include()]] line.
+                # this is an <<Include()>> line.
                 # now parse the included page and do the work on it.
 
                 ## get heading and level from Include() line.
@@ -101,7 +101,7 @@ class TableOfContents:
                 else:
                     # no pagename?  ignore it
                     continue
-                if tmp.group("heading"):
+                if tmp.group("heading") and tmp.group("hquote"):
                     if tmp.group("htext"):
                         heading = tmp.group("htext")
                     else:
@@ -110,12 +110,12 @@ class TableOfContents:
                         level = int(tmp.group("level"))
                     else:
                         level = 1
-                    inc_page_lines = ["%s %s %s" %("=" * level, heading, "=" * level)]
+                    inc_page_lines = ["%s %s %s" % ("=" * level, heading, "=" * level)]
                 else:
                     inc_page_lines = []
 
                 inc_page_lines = inc_page_lines + self.IncludeMacro(self.macro, match.group(1), called_by_toc=1)
-                
+
                 self.process_lines(inc_page_lines, inc_pagename)
             else:
                 self.parse_line(line, pagename)
@@ -123,7 +123,8 @@ class TableOfContents:
     def parse_line(self, line, pagename):
         # FIXME this also finds "headlines" in {{{ code sections }}}:
         match = self.head_re.match(line)
-        if not match: return
+        if not match:
+            return
         title_text = match.group('htext').strip()
         pntt = pagename + title_text
         self.titles.setdefault(pntt, 0)
@@ -131,19 +132,19 @@ class TableOfContents:
 
         # Get new indent level
         newindent = len(match.group('hmarker'))
-        if newindent > self.maxdepth: return
-        if newindent < self.mindepth: return
+        if newindent > self.maxdepth or newindent < self.mindepth:
+            return
         if not self.indent:
             self.baseindent = newindent - 1
             self.indent = self.baseindent
 
         # Close lists
-        for i in range(0,self.indent-newindent):
+        for dummy in range(0, self.indent-newindent):
             self.result.append(self.macro.formatter.listitem(0))
             self.result.append(self.macro.formatter.number_list(0))
 
         # Open Lists
-        for i in range(0,newindent-self.indent):
+        for dummy in range(0, newindent-self.indent):
             self.result.append(self.macro.formatter.number_list(1))
             self.result.append(self.macro.formatter.listitem(1))
 
@@ -155,7 +156,7 @@ class TableOfContents:
         # close last listitem if same level
         if self.indent == newindent:
             self.result.append(self.macro.formatter.listitem(0))
-            
+
         if self.indent >= newindent:
             self.result.append(self.macro.formatter.listitem(1))
         self.result.append(self.macro.formatter.anchorlink(1,
@@ -167,5 +168,6 @@ class TableOfContents:
         self.indent = newindent
 
 def execute(macro, args):
-    toc=TableOfContents(macro,args)
+    toc = TableOfContents(macro, args)
     return toc.run()
+
