@@ -4,28 +4,31 @@
 
     This macro creates a hitcount chart from the data in "event.log".
 
-    TODO: refactor to use a class, this code is ugly. A lot of code
-    here is duplicated in stats.useragents. Maybe both can use same
-    base class, maybe some parts are useful to other code.
+    TODO: refactor to use a class, this code is ugly.
+          A lot of code here is duplicated in stats.useragents.
+          Maybe both can use same base class, maybe some parts are useful to other code.
 
-    @copyright: 2002-2004 by Jrgen Hermann <jh@web.de>
+    @copyright: 2002-2004 Juergen Hermann <jh@web.de>,
+                2007 MoinMoin:ThomasWaldmann
     @license: GNU GPL, see COPYING for details.
 """
 
 _debug = 0
 
-from MoinMoin import caching, config, wikiutil
-from MoinMoin.Page import Page
-from MoinMoin.util import MoinMoinNoFooter
-from MoinMoin.formatter.text_html import Formatter
-from MoinMoin.logfile import eventlog, logfile
+import time
 
+from MoinMoin import caching, wikiutil, logfile
+from MoinMoin.Page import Page
+from MoinMoin.logfile import eventlog
+
+# this is a CONSTANT used for on-disk caching, it must NOT be configurable and
+# not depend on request.user!
+DATE_FMT = '%04d-%02d-%02d' # % (y, m, d)
 
 def linkto(pagename, request, params=''):
     _ = request.getText
 
     if not request.cfg.chart_options:
-        request.formatter = Formatter(request)
         return text(pagename, request, params)
 
     if _debug:
@@ -39,9 +42,8 @@ def linkto(pagename, request, params=''):
     querystr = wikiutil.escape(querystr)
     if params:
         querystr += '&amp;' + params
-    
-    # TODO: remove escape=0 in 2.0
-    data = {'url': page.url(request, querystr, escape=0)}
+
+    data = {'url': page.url(request, querystr)}
     data.update(request.cfg.chart_options)
     result = ('<img src="%(url)s" width="%(width)d" height="%(height)d"'
               ' alt="hitcounts chart">') % data
@@ -50,19 +52,20 @@ def linkto(pagename, request, params=''):
 
 
 def get_data(pagename, request, filterpage=None):
-    
+    cache_days, cache_views, cache_edits = [], [], []
+    cache_date = 0
+
     # Get results from cache
     if filterpage:
         arena = Page(request, pagename)
+        cache = caching.CacheEntry(request, arena, 'hitcounts', scope='item', use_pickle=True)
     else:
         arena = 'charts'
-    
-    cache_days, cache_views, cache_edits = [], [], []
-    cache_date = 0
-    cache = caching.CacheEntry(request, arena, 'hitcounts')
+        cache = caching.CacheEntry(request, arena, 'hitcounts', scope='wiki', use_pickle=True)
+
     if cache.exists():
         try:
-            cache_date, cache_days, cache_views, cache_edits = eval(cache.content())
+            cache_date, cache_days, cache_views, cache_edits = cache.content()
         except:
             cache.remove() # cache gone bad
 
@@ -72,7 +75,7 @@ def get_data(pagename, request, filterpage=None):
         new_date = log.date()
     except logfile.LogMissing:
         new_date = None
-        
+
     # prepare data
     days = []
     views = []
@@ -82,35 +85,35 @@ def get_data(pagename, request, filterpage=None):
     if new_date is not None:
         log.set_filter(['VIEWPAGE', 'SAVEPAGE'])
         for event in log.reverse():
-            #print ">>>", wikiutil.escape(repr(event)), "<br>"
-    
-            if event[0] <=  cache_date:
+            event_usecs = event[0]
+            if event_usecs <= cache_date:
                 break
-            # XXX Bug: event[2].get('pagename') -> u'Aktuelle%C4nderungen' 8(
-            eventpage = event[2].get('pagename','')
+            eventpage = event[2].get('pagename', '')
             if filterpage and eventpage != filterpage:
                 continue
-            time_tuple = request.user.getTime(wikiutil.version2timestamp(event[0]))
+            event_secs = wikiutil.version2timestamp(event_usecs)
+            time_tuple = time.gmtime(event_secs) # must be UTC
             day = tuple(time_tuple[0:3])
             if day != ratchet_day:
                 # new day
                 while ratchet_time:
-                    ratchet_time -= 86400
-                    rday = tuple(request.user.getTime(ratchet_time)[0:3])
-                    if rday <= day: break
-                    days.append(request.user.getFormattedDate(ratchet_time))
+                    ratchet_time -= 86400 # seconds per day
+                    rday = tuple(time.gmtime(ratchet_time)[0:3]) # must be UTC
+                    if rday <= day:
+                        break
+                    days.append(DATE_FMT % rday)
                     views.append(0)
                     edits.append(0)
-                days.append(request.user.getFormattedDate(wikiutil.version2timestamp(event[0])))
+                days.append(DATE_FMT % day)
                 views.append(0)
                 edits.append(0)
                 ratchet_day = day
-                ratchet_time = wikiutil.version2timestamp(event[0])
+                ratchet_time = event_secs
             if event[1] == 'VIEWPAGE':
-                views[-1] = views[-1] + 1
+                views[-1] += 1
             elif event[1] == 'SAVEPAGE':
-                edits[-1] = edits[-1] + 1
-    
+                edits[-1] += 1
+
         days.reverse()
         views.reverse()
         edits.reverse()
@@ -126,8 +129,7 @@ def get_data(pagename, request, filterpage=None):
     cache_views.extend(views)
     cache_edits.extend(edits)
     if new_date is not None:
-        cache.update("(%r, %r, %r, %r)" % 
-                     (new_date, cache_days, cache_views, cache_edits))
+        cache.update((new_date, cache_days, cache_views, cache_edits))
 
     return cache_days, cache_views, cache_edits
 
@@ -140,18 +142,19 @@ def text(pagename, request, params=''):
     # check params
     filterpage = None
     if params.startswith('page='):
-        params = params[len('page='):]        
+        params = params[len('page='):]
+        params = wikiutil.url_unquote(params, want_unicode=False)
         filterpage = wikiutil.decodeUserInput(params)
-    
-    if request and request.form and request.form.has_key('page'):
+
+    if request and request.form and 'page' in request.form:
         filterpage = request.form['page'][0]
 
     days, views, edits = get_data(pagename, request, filterpage)
 
     hits = TupleDataset()
-    hits.columns = [Column('day', label=_("Date"), align='left'),
-                    Column('views', label=_("Views/day") , align='right'),
-                    Column('edits', label=_("Edits/day") , align='right')
+    hits.columns = [Column('day', label=_("Date", formatted=False), align='left'),
+                    Column('views', label=_("Views/day", formatted=False), align='right'),
+                    Column('edits', label=_("Edits/day", formatted=False), align='right'),
                     ]
 
     maxentries = 30
@@ -160,14 +163,14 @@ def text(pagename, request, params=''):
         step = float(len(days))/ maxentries
     else:
         step = 1
-        
+
     sv = 0.0
     se = 0.0
     sd = 0.0
     cnt = 0
 
-    for i in xrange(len(days)-1,-1,-1):
-        d,v,e = days[i], views[i], edits[i]
+    for i in xrange(len(days)-1, -1, -1):
+        d, v, e = days[i], views[i], edits[i]
         # sum up views and edits to step days 
         sd += 1
         cnt += 1
@@ -193,13 +196,13 @@ def draw(pagename, request):
 
     # check params
     filterpage = None
-    if request and request.form and request.form.has_key('page'):
+    if request and request.form and 'page' in request.form:
         filterpage = request.form['page'][0]
 
     days, views, edits = get_data(pagename, request, filterpage)
 
     import math
-    
+
     try:
         scalefactor = float(max(views))/max(edits)
     except (ZeroDivisionError, ValueError):
@@ -207,8 +210,8 @@ def draw(pagename, request):
     else:
         scalefactor = int(10 ** math.floor(math.log10(scalefactor)))
 
-    #scale edits up
-    edits = map(lambda x: x*scalefactor, edits)
+    # scale edits up
+    edits = [x * scalefactor for x in edits]
 
     # create image
     image = cStringIO.StringIO()
@@ -216,16 +219,20 @@ def draw(pagename, request):
     c.addData(ChartData(views, color='green'))
     c.addData(ChartData(edits, color='red'))
     chart_title = ''
-    if request.cfg.sitename: chart_title = "%s: " % request.cfg.sitename
-    chart_title = chart_title + _('Page hits and edits')
-    if filterpage: chart_title = _("%(chart_title)s for %(filterpage)s") % {
-        'chart_title': chart_title, 'filterpage': filterpage}
-    chart_title = "%s\n%sx%d" % (chart_title, _("green=view\nred=edit"), scalefactor)
+    if request.cfg.sitename:
+        chart_title = "%s: " % request.cfg.sitename
+    chart_title = chart_title + _('Page hits and edits', formatted=False)
+    if filterpage:
+        chart_title = _("%(chart_title)s for %(filterpage)s", formatted=False) % {
+            'chart_title': chart_title,
+            'filterpage': filterpage,
+        }
+    chart_title = "%s\n%sx%d" % (chart_title, _("green=view\nred=edit", formatted=False), scalefactor)
     c.option(
-        title = chart_title.encode('iso-8859-1', 'replace'), # gdchart can't do utf-8
-        xtitle = (_('date') + ' (Server)').encode('iso-8859-1', 'replace'),
-        ytitle = _('# of hits').encode('iso-8859-1', 'replace'),
-        title_font = c.GDC_GIANT,
+        title=chart_title.encode('iso-8859-1', 'replace'), # gdchart can't do utf-8
+        xtitle=(_('date', formatted=False) + ' (Server)').encode('iso-8859-1', 'replace'),
+        ytitle=_('# of hits', formatted=False).encode('iso-8859-1', 'replace'),
+        title_font=c.GDC_GIANT,
         #thumblabel = 'THUMB', thumbnail = 1, thumbval = 10,
         #ytitle_color = Color('green'),
         #yaxis2 = 1,
@@ -233,23 +240,21 @@ def draw(pagename, request):
         #ytitle2_color = Color('red'),
         #ylabel2_color = Color('black'),
         #interpolations = 0,
-        threed_depth = 1.0,
-        requested_yinterval = 1.0,
-        stack_type = c.GDC_STACK_BESIDE
+        threed_depth=1.0,
+        requested_yinterval=1.0,
+        stack_type=c.GDC_STACK_BESIDE
     )
     c.draw(c.GDC_LINE,
         (request.cfg.chart_options['width'], request.cfg.chart_options['height']),
         image, days)
 
-    # send HTTP headers
     headers = [
         "Content-Type: image/gif",
         "Content-Length: %d" % len(image.getvalue()),
     ]
-    request.http_headers(headers)
+    request.emit_http_headers(headers)
 
     # copy the image
     image.reset()
     shutil.copyfileobj(image, request, 8192)
-    raise MoinMoinNoFooter
 
