@@ -7,16 +7,28 @@
     @license: GNU GPL, see COPYING for details.
 """
 
-import os, sys, re
+import os, sys, re, random
+
+# do the pickle magic once here, so we can just import from here:
+# cPickle can encode normal and Unicode strings
+# see http://docs.python.org/lib/node66.html
+try:
+    import cPickle as pickle
+except ImportError:
+    import pickle
+
+# Set pickle protocol, see http://docs.python.org/lib/node64.html
+PICKLE_PROTOCOL = pickle.HIGHEST_PROTOCOL
+
 
 #############################################################################
 ### XML helper functions
 #############################################################################
 
 g_xmlIllegalCharPattern = re.compile('[\x01-\x08\x0B-\x0D\x0E-\x1F\x80-\xFF]')
-g_undoUtf8Pattern       = re.compile('\xC2([^\xC2])')
-g_cdataCharPattern      = re.compile('[&<\'\"]')
-g_textCharPattern       = re.compile('[&<]')
+g_undoUtf8Pattern = re.compile('\xC2([^\xC2])')
+g_cdataCharPattern = re.compile('[&<\'\"]')
+g_textCharPattern = re.compile('[&<]')
 g_charToEntity = {
     '&': '&amp;',
     '<': '&lt;',
@@ -31,7 +43,7 @@ def TranslateCDATA(text):
     """
     new_string, num_subst = re.subn(g_undoUtf8Pattern, lambda m: m.group(1), text)
     new_string, num_subst = re.subn(g_cdataCharPattern, lambda m, d=g_charToEntity: d[m.group()], new_string)
-    new_string, num_subst = re.subn(g_xmlIllegalCharPattern, lambda m: '&#x%02X;'%ord(m.group()), new_string)
+    new_string, num_subst = re.subn(g_xmlIllegalCharPattern, lambda m: '&#x%02X;' % ord(m.group()), new_string)
     return new_string
 
 def TranslateText(text):
@@ -41,18 +53,10 @@ def TranslateText(text):
     """
     new_string, num_subst = re.subn(g_undoUtf8Pattern, lambda m: m.group(1), text)
     new_string, num_subst = re.subn(g_textCharPattern, lambda m, d=g_charToEntity: d[m.group()], new_string)
-    new_string, num_subst = re.subn(g_xmlIllegalCharPattern, lambda m: '&#x%02X;'%ord(m.group()), new_string)
+    new_string, num_subst = re.subn(g_xmlIllegalCharPattern, lambda m: '&#x%02X;' % ord(m.group()), new_string)
     return new_string
 
 
-#############################################################################
-### Exceptions
-#############################################################################
-
-class MoinMoinNoFooter(Exception):
-    """Raised by actions to prevent output of a page footer (with timings)."""
-    pass
-
 #############################################################################
 ### Misc
 #############################################################################
@@ -68,11 +72,11 @@ def rangelist(numbers):
     for i in range(len(numbers)-1):
         if pattern[-1] == ',':
             pattern = pattern + str(numbers[i])
-            if numbers[i]+1 == numbers[i+1]:
+            if numbers[i] + 1 == numbers[i+1]:
                 pattern = pattern + '-'
             else:
                 pattern = pattern + ','
-        elif numbers[i]+1 != numbers[i+1]:
+        elif numbers[i] + 1 != numbers[i+1]:
             pattern = pattern + str(numbers[i]) + ','
 
     if pattern[-1] in ',-':
@@ -85,9 +89,9 @@ def dumpFormData(form):
     from MoinMoin import wikiutil
 
     result = '<dt><strong>Form entries</strong></dt>'
-    for k in form.keys():
+    for k in form:
         v = form.get(k, ["<empty>"])
-        v = "|".join(v) 
+        v = "|".join(v)
         result = result + '<dd><em>%s</em>=%s</dd>' % (k, wikiutil.escape(v))
 
     return result
@@ -108,15 +112,20 @@ class simpleIO:
 
     def __init__(self):
         self.buffer = []
-        
+
     def write(self, foo):
         if not isinstance(foo, unicode):
             foo = foo.decode("iso-8859-1", "replace")
         self.buffer.append(foo)
-    
+
     def getvalue(self):
         return u''.join(self.buffer)
 
     def close(self):
         self.buffer = None
 
+
+def random_string(length):
+    chars = ''.join([chr(random.randint(0, 255)) for dummy in xrange(length)])
+    return chars
+
