@@ -27,7 +27,7 @@ sys.path.insert(0, '/path/to/wikiconfig')
 ## import os
 ## os.environ['MOIN_DEBUG'] = '1'
 
-from MoinMoin.server.twistedmoin import TwistedConfig, makeApp
+from MoinMoin.server.server_twisted import TwistedConfig, makeApp
 
 
 class Config(TwistedConfig):
@@ -39,6 +39,11 @@ class Config(TwistedConfig):
     # Path to moin shared files (default '/usr/share/moin/wiki/htdocs')
     docs = '/usr/share/moin/htdocs'
 
+    # URL prefix for the static stuff (used to access stuff in docs) - you
+    # usually should not need to change this because Twisted moin uses
+    # matching defaults for here and for wikiconfig.py:
+    #url_prefix_static = '/moin_static162'
+
     # The server will run with as this user and group (default 'www-data')
     user = 'www-data'
     group = 'www-data'
@@ -65,7 +70,10 @@ class Config(TwistedConfig):
     # Leaving this as None will have no Apache compatible log file. Apache
     # compatible logfiles are useful because there are quite a few programs
     # which analyze them and display statistics.
-    ## logPath = 'mointwisted.log'
+    ## logPath_twisted = 'mointwisted.log'
+
+    # moin log file
+    ## logPath = 'moin.log'
 
     # Memory profile (default commented)
     # Useful only if you are a developer or interested in moin memory usage
@@ -73,7 +81,7 @@ class Config(TwistedConfig):
     ## memoryProfile = TwistedProfiler('mointwisted',
     ##                            requestsPerSample=100,
     ##                            collect=0)
-    
+
     # Hotshot profile (default commented)
     # Not compatible with threads.
     ## hotshotProfile = name + '.prof'
